@@ -18,11 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+/* if you define DEBUG here you will get debug output from all Bluefish parts */
+/* #define DEBUG */
+
 #ifndef __BLUEFISH_H_
 #define __BLUEFISH_H_
 
-/*#define DEBUG*/
-
 #include "config.h"
 #define BLUEFISH_SPLASH_FILENAME PKGDATADIR"bluefish_splash.png"
 
@@ -61,6 +62,14 @@ extern void g_none(...);
 
 #include <sys/types.h>
 #include <regex.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
+
+#ifdef HAVE_GNOME_VFS
+#include <libgnomevfs/gnome-vfs.h>
+#endif
+
 
 /*********************/
 /* undo/redo structs */
@@ -92,8 +101,6 @@ typedef struct {
 	GdkPixbuf *icon;
 	gchar *update_chars;
 	GList *highlightlist;
-	GtkWidget *menuitem; /* the menuitem to choose this for highlighting */
-	gulong menuitem_activate_id;
 	gboolean editable; /* this a type that can be edited by Bluefish */
 	gchar *content_regex; /* a regex pattern to test the filetype using the content */
 } Tfiletype;
@@ -101,15 +108,19 @@ typedef struct {
 /*******************/
 /* document struct */
 /*******************/
+#define BFWIN(var) ((Tbfwin *)(var))
+#define DOCUMENT(var) ((Tdocument *)(var))
 
 typedef struct {
-	gchar *filename;
+	gchar *filename; /* or NULL if no filename known */
 	gchar *encoding;
 	gint modified;
-	time_t mtime; /* from stat() */
-	uid_t owner_uid; /* user ID of owner */
-	gid_t owner_gid; /* group ID of owner */
-	mode_t mode; /* mode field in stat() format so any stat macro's will work*/
+/*	time_t mtime; */ /* from stat() */
+#ifdef HAVE_GNOME_VFS
+	GnomeVFSFileInfo *fileinfo;
+#else /* HAVE_GNOME_VFS */
+	struct stat statbuf;
+#endif /* HAVE_GNOME_VFS */
 	gint is_symlink; /* file is a symbolic link */
 	gulong del_txt_id; /* text delete signal */
 	gulong ins_txt_id; /* text insert signal */
@@ -126,6 +137,8 @@ typedef struct {
 	gboolean wrapstate; /* does this document use wrap?*/
 	gboolean linenumberstate; /* does this document use linenumbers? */
 	gboolean overwrite_mode; /* is document in overwrite mode */
+	gpointer floatingview; /* a 2nd textview widget that has its own window */
+	gpointer bfwin;
 } Tdocument;
 
 typedef struct {
@@ -135,8 +148,8 @@ typedef struct {
 	gint view_left_panel;  	/* view filebrowser/functionbrowser etc. */
 	gint view_line_numbers; /* view line numbers on the left side by default */
 	gint filebrowser_show_hidden_files;
-	gint filebrowser_show_others_files;
 	gint filebrowser_show_backup_files;
+	gint filebrowser_two_pane_view; /* have one or two panes in the filebrowser */
 	gchar *filebrowser_unknown_icon;
 	gchar *filebrowser_dir_icon;
 	gchar *editor_font_string;		/* editor font */
@@ -145,7 +158,7 @@ typedef struct {
 	gchar *tab_font_string;		/* notebook tabs font */
 	GList *browsers; /* browsers array */
 	GList *external_commands;	/* external commands array */
-	GList *cust_menu; 		/* entries in the custom menu */
+	GList *cust_menu; 		/* DEPRECATED entries in the custom menu */
 	GList *cmenu_insert; /* custom menu inserts */
 	GList *cmenu_replace; /* custom menu replaces */
 	GList *quickbar_items; /* items in the quickbar toolbar */
@@ -159,6 +172,7 @@ typedef struct {
 	gint transient_htdialogs;  /* set html dialogs transient ro the main window */
 	gint restore_dimensions; /* use the dimensions as used the previous run */
 	gint left_panel_width; 	/* width of filelist */
+	gint two_pane_filebrowser_height; /* position of the pane separater on the two paned file browser */
 	gint main_window_h;			/* main window height */
 	gint main_window_w;			/* main window width */
 	gint max_recent_files;	/* length of Open Recent list */
@@ -175,12 +189,14 @@ typedef struct {
 	gint image_thumbnailsizing_val2; /* height if the type=3 */
 	gchar *image_thumnailformatstring; /* like <a href="%r"><img src="%t"></a> or more advanced */
 	gint allow_multi_instances; /* allow multiple instances of the same file */
+	gint modified_check_type; /* 0=no check, 1=by mtime and size, 2=by mtime, 3=by size, 4,5,...not implemented (md5sum?) */
 	gint num_undo_levels; 	/* number of undo levels per document */
 	gint clear_undo_on_save; 	/* clear all undo information on file save */
 	gchar *newfile_default_encoding; /* if you open a new file, what encoding will it use */
 	GList *encodings; /* all encodings you can choose from */
 	gint auto_set_encoding_meta; /* auto set metatag for the encoding */
 	gint auto_update_meta; /* auto update author and generator meta tags on save */
+	gint encoding_search_Nbytes; /* number of bytes to look for the encoding meta tag */
 	GList *outputbox; /* all outputbox commands */
 	gint ext_browsers_in_submenu;
 	gint ext_commands_in_submenu;
@@ -190,10 +206,11 @@ typedef struct {
 	gint fref_info_type; /* type of info shown in a small function reference window */
 	gint document_tabposition;
 	gint leftpanel_tabposition;
+	gchar *default_basedir;
+	gchar *project_suffix;
 #ifdef HAVE_LIBASPELL
 	gchar *spell_default_lang;
 #endif /* HAVE_LIBASPELL */
-	gint default_advanced_snr;
 	gint cont_highlight_full; 	/* if you want to highlight the full text or just the line */
 	gint lasttime_cust_menu; /* the last time the defaultfile was checked for new entries */
 	gint lasttime_highlighting; /* see above */
@@ -229,14 +246,44 @@ typedef struct {
 	gchar *shift_enter_text;	/* inserted text */
 	gint conv_special_char;		/* convert ctrl-'<','>','&' */
 	gint open_in_running_bluefish; /* open commandline documents in already running session*/
-
 } Tproperties;
 
 typedef struct {
+	GList *classlist;
+	GList *colorlist;
+	GList *targetlist;
+	GList *urllist;
+	GList *fontlist;
+	GList *dtd_cblist; /* is this used ?? */
+	GList *headerlist; /* is this used ?? */
+	GList *positionlist; /* is this used ?? */
+	GList *searchlist; /* used in snr2 */
+	GList *replacelist; /* used in snr2 */
+} Tsessionvars;
+
+typedef struct {
+	gchar *filename;
+	gchar *name;
+	GList *files;
+	gchar *basedir;
+	gchar *webdir;
+	gchar *template;
+	gpointer editor;
+	GList *recentfiles;
+	gint view_main_toolbar;
+	gint view_left_panel;
+	gint view_custom_menu;
+	gint view_html_toolbar;
+	gint word_wrap;
+	Tsessionvars *session;
+} Tproject;
+
+typedef struct {
+	Tsessionvars *session;
 	Tdocument *current_document; /* one object out of the documentlist, the current visible document */
-	Tproperties props;
 	GList *documentlist; /* document.c and others: all Tdocument objects */
-	GList *filetypelist; /* highlighting.c: a list of all filetypes with their icons and highlighting sets */
+	Tdocument *last_activated_doc;
+	Tproject *project; /* might be NULL for a default project */
 	GtkWidget *main_window;
 	GtkWidget *menubar;
 	gint last_notebook_page; /* a check to see if the notebook changed to a new page */
@@ -250,11 +297,55 @@ typedef struct {
 	GtkWidget *statusbar_lncol; /* where we have the line number */
 	GtkWidget *statusbar_insovr; /* insert/overwrite indicator */
 	GtkWidget *statusbar_editmode; /* editor mode and doc encoding */
+	/* the following list contains toolbar widgets we like to reference later on */
+	GtkWidget *toolbar_undo;
+	GtkWidget *toolbar_redo;
+	GtkWidget *toolbar_quickbar; /* the quickbar widget */
+	GList *toolbar_quickbar_children; /* this list is needed to remove widgets from the quickbar */
+	/* following widgets are used to show/hide stuff */
+	GtkWidget *main_toolbar_hb;
+	GtkWidget *html_toolbar_hb;
+	GtkWidget *custom_menu_hb; /* handle box for custom menu */
+	GtkWidget *output_box;
+	GtkWidget *leftpanel_notebook;
+	/* following are lists with dynamic menu entries */
+	GList *menu_recent_files;
+	GList *menu_recent_projects;
+	GList *menu_external;
+	GList *menu_encodings;
+	GList *menu_outputbox;
+	GList *menu_windows;
+	GtkWidget *menu_cmenu;
+	GList *menu_cmenu_entries;
+	GList *menu_filetypes;
+	/* following is a new approach, that we have only a gpointer here, whioh is typecasted 
+	in the file where it is needed */
+	gpointer outputbox;
+	gpointer bfspell;
+	gpointer filebrowser;
+	gpointer snr2;
+	gpointer fref;
+#ifdef BOOKMARKS	
+	gpointer bmark;
+#endif /* BOOKMARKS */	
+} Tbfwin;
+
+typedef struct {
+	Tproperties props;
+	GList *filetypelist; /* highlighting.c: a list of all filetypes with their icons and highlighting sets */
+	GList *bfwinlist;
 	GList *recent_directories; /* a stringlist with the most recently used directories */
+	gpointer filebrowserconfig;
+	gpointer frefdata;
+#ifdef BOOKMARKS	
+	gpointer bmarkdata;
+#endif /* BOOKMARKS */	
+	gint num_untitled_documents;
 } Tmain;
 
 extern Tmain *main_v;
 
 /* public functions from bluefish.c */
-void bluefish_exit_request();
+void bluefish_exit_request(void);
+void free_session(Tsessionvars *session);
 #endif /* __BLUEFISH_H_ */
