@@ -48,6 +48,34 @@ void flush_queue(void) {
 		g_main_context_iteration (NULL, TRUE);
 	}
 }
+/**
+ * widget_get_string_size:
+ * @widget: #GtkWidget* to put the string on
+ * @string: #ghcar* with the string
+ *
+ * This function will calculate the width in pixels from the
+ * string passed to it in string, using the font from widget
+ *
+ * Return value: #gint pixels
+ */
+gint widget_get_string_size(GtkWidget *widget, gchar *string) {
+	PangoLayout *layout;
+	gint retval = -1;
+	layout = gtk_widget_create_pango_layout(widget,string);
+	if (layout != NULL) {
+		pango_layout_get_pixel_size(layout, &retval, NULL);
+		g_object_unref(G_OBJECT (layout));
+	}
+	return retval;
+}
+
+void widget_set_visible(GtkWidget *widget, gboolean visible) {
+	if (visible) {
+		gtk_widget_show(widget);
+	} else {
+		gtk_widget_hide(widget);	
+	}
+}
 
 /**
  * window_destroy:
@@ -545,7 +573,7 @@ static gboolean window_full_key_press_event_lcb(GtkWidget *widget,GdkEventKey *e
  * @delete_on_escape: #gboolean if the escape key should close the dialog
  * @transientforparent: #GtkWidget* with the window to set this transient for, or NULL
  *
- * 	Create new window with title, callback functions, some more settings
+ * Create new window with title, callback functions, some more settings
  * and if needed set a callback so the window will be closed on escape press
  * and set it if needed transient for another window
  *
@@ -641,38 +669,70 @@ GtkWidget *apply_font_style(GtkWidget * this_widget, gchar * fontstring) {
  *
  * Return value: #GtkWidget* to the hbox
  */
-GtkWidget *hbox_with_pix_and_text(const gchar *label, gint pixmap_type) {
+GtkWidget *hbox_with_pix_and_text(const gchar *label, gint bf_pixmaptype, gboolean w_mnemonic) {
 	GtkWidget *hbox = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(hbox), new_pixmap(pixmap_type), FALSE, FALSE, 1);
-	gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new_with_mnemonic(label), TRUE, TRUE, 1);
+	gtk_box_pack_start(GTK_BOX(hbox), new_pixmap(bf_pixmaptype), FALSE, FALSE, 1);
+	gtk_box_pack_start(GTK_BOX(hbox), ((w_mnemonic) ? gtk_label_new_with_mnemonic(label) : gtk_label_new(label)), TRUE, TRUE, 1);
 	gtk_widget_show_all(hbox);
 	return hbox;
 }
-/**
- * bf_generic_button_with_image:
- * @label: #const gchar* button string with '_' for the mnemonic
- * @pixmap_type: #gint image to display on button know to new_pixmap() from pixmap.c
- * @func: #GCallback pointer to signal handler
- * @func_data: #gpointer data for signal handler
- *
- * 	Create new button with an image and connect the "clicked" signal to func
- *
- * Return value: #GtkWidget* pointer to created button
- */
-GtkWidget *bf_generic_button_with_image(const gchar *label, gint pixmap_type, GCallback func, gpointer func_data) {
-        GtkWidget *button;
 
-	button = gtk_button_new();
-	gtk_container_set_border_width(GTK_CONTAINER(button), 0);
-	gtk_container_add(GTK_CONTAINER(button), hbox_with_pix_and_text(label, pixmap_type));
+GtkWidget *bf_allbuttons_backend(const gchar *label, gboolean w_mnemonic, gint bf_pixmaptype, GCallback func, gpointer func_data) {
+	GtkWidget *button;
+	if (bf_pixmaptype == -1) {
+		/* there is no image needed, only text */
+		if (w_mnemonic) {
+			button = gtk_button_new_with_mnemonic(label);
+		} else {
+			button = gtk_button_new_with_label(label);
+		}
+	} else {
+		/* there is an image needed */
+		button = gtk_button_new();
+		if (label) {
+			/* both a pixmap and text */
+			gtk_container_set_border_width(GTK_CONTAINER(button), 0);
+			gtk_container_add(GTK_CONTAINER(button), hbox_with_pix_and_text(label, bf_pixmaptype, w_mnemonic));
+		} else {
+			/* only pixmap */
+			gtk_container_add(GTK_CONTAINER(button), new_pixmap(bf_pixmaptype));
+		}
+	}
 	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
-	g_return_val_if_fail(button, NULL);
 	g_signal_connect(G_OBJECT(button), "clicked", func, func_data);
 	return button;
 }
 
 /**
- * bf_stock_button:
+ * bf_generic_button_with_image:
+ * @label: #const gchar* button string with '_' for the mnemonic, or NULL
+ * @pixmap_type: #gint image to display on button know to new_pixmap() from pixmap.c
+ * @func: #GCallback pointer to signal handler
+ * @func_data: #gpointer data for signal handler
+ *
+ * Create new button with an image and connect the "clicked" signal to func
+ * if the label is NULL there will be only an image in the button
+ *
+ * Return value: #GtkWidget* pointer to created button
+ */
+/* GtkWidget *bf_generic_button_with_image(const gchar *label, gint pixmap_type, GCallback func, gpointer func_data) {
+        GtkWidget *button;
+
+	button = gtk_button_new();
+	gtk_container_set_border_width(GTK_CONTAINER(button), 0);
+	if (label) {
+		gtk_container_add(GTK_CONTAINER(button), hbox_with_pix_and_text(label, pixmap_type));
+	} else {
+		gtk_container_add(GTK_CONTAINER(button), new_pixmap(pixmap_type));
+	}
+	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
+	g_return_val_if_fail(button, NULL);
+	g_signal_connect(G_OBJECT(button), "clicked", func, func_data);
+	return button;
+} */
+
+/**
+ * bf_generic_mnemonic_button:
  * @Text: #const gchar* button string, using '_' for the mnemonic
  * @func: #GCallback pointer to signal handler
  * @func_data: #gpointer data for signal handler
@@ -681,16 +741,16 @@ GtkWidget *bf_generic_button_with_image(const gchar *label, gint pixmap_type, GC
  *
  * Return value: pointer to created button
  */
-GtkWidget *bf_stock_button(const gchar * Text, GCallback func, gpointer func_data) {
+/* GtkWidget *bf_generic_mnemonic_button(const gchar * Text, GCallback func, gpointer func_data) {
 	GtkWidget *button;
 
 	button = gtk_button_new_with_mnemonic(Text);
 	g_return_val_if_fail(button, NULL);
 	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
 	g_signal_connect(G_OBJECT(button), "clicked", func, func_data);
-	DEBUG_MSG("bf_stock_button, func_data=%p\n", func_data);
+	DEBUG_MSG("bf_generic_mnemonic_button, func_data=%p\n", func_data);
 	return button;
-}
+} */
 /**
  * bf_gtkstock_button:
  * @stock_id: #const gchar* wioth the GTK stock icon ID
@@ -702,10 +762,7 @@ GtkWidget *bf_stock_button(const gchar * Text, GCallback func, gpointer func_dat
  * Return value: pointer to created button
  */
 GtkWidget *bf_gtkstock_button(const gchar * stock_id, GCallback func, gpointer func_data) {
-	GtkWidget *button;
-
-	button = gtk_button_new_from_stock(stock_id);
-	g_return_val_if_fail(button, NULL);
+	GtkWidget *button = gtk_button_new_from_stock(stock_id);
 	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
 	g_signal_connect(G_OBJECT(button), "clicked", func, func_data);
 	return button;
@@ -754,7 +811,7 @@ void bf_mnemonic_label_tad_with_alignment(const gchar *labeltext, GtkWidget *m_w
 
 	label = gtk_label_new_with_mnemonic(labeltext);
 	gtk_misc_set_alignment(GTK_MISC(label), xalign, yalign);
-	gtk_table_attach(GTK_TABLE(table), label, left_attach, right_attach, top_attach, bottom_attach, GTK_FILL, GTK_FILL, 0, 0);  
+	gtk_table_attach(GTK_TABLE(table), label, left_attach, right_attach, top_attach, bottom_attach, GTK_FILL, GTK_FILL, 0, 0);
   
 	if (m_widget != NULL) {
 		if (GTK_IS_COMBO(m_widget)) {
@@ -789,8 +846,54 @@ void bf_label_tad_with_markup(const gchar *labeltext, gfloat xalign, gfloat yali
 	gtk_label_set_markup(GTK_LABEL(label), labeltext);
 	gtk_misc_set_alignment(GTK_MISC(label), xalign, yalign);
 	gtk_table_attach_defaults(GTK_TABLE(table), label, left_attach, right_attach, top_attach, bottom_attach);	
-}								
+}
+#ifdef NOTYETUSED
+typedef struct {
+	GtkWidget *win;
+	GtkWidget *entry[10];
+	gpointer data;
+} Tmultientrywidget;
 
+static void multi_entry_destroy(GtkObject *object, Tmultientrywidget *mew) {
+	g_free(mew);
+}
+
+static void multi_entry_cancel_clicked(GtkWidget *widget, Tmultientrywidget *mew) {
+	gtk_widget_destroy(mew->win);
+}
+
+Tmultientrywidget *build_multi_entry_window(gchar *title,GCallback ok_func
+			,gpointer data, const gchar **labelarr) {
+	gint arrlen,i;
+	GtkWidget *table,*hbox,*but;
+
+	arrlen = count_array(labelarr);
+	if (arrlen >10) arrlen = 10;
+	Tmultientrywidget *mew = g_new0(Tmultientrywidget,1);
+	mew->data = data;
+	mew->win = window_full2(title, GTK_WIN_POS_MOUSE, 10, multi_entry_destroy,mew, TRUE, NULL);
+	table = gtk_table_new(arrlen+2,2,FALSE);
+	gtk_table_set_row_spacings(GTK_TABLE(table),6);
+	gtk_table_set_col_spacings(GTK_TABLE(table),6);
+	gtk_container_add(GTK_CONTAINER(mew->win),table);
+	for (i=0;i<arrlen;i++) {
+		GtkWidget *label = gtk_label_new(labelarr[i]);
+		gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, i, i+1);
+		mew->entry[i] = entry_with_text(NULL, 255);
+		gtk_table_attach_defaults(GTK_TABLE(table), mew->entry[i], 1, 2, i, i+1);
+	}
+	gtk_table_attach_defaults(GTK_TABLE(table), gtk_hseparator_new(), 0, 2, i, i+1);
+	hbox = gtk_hbutton_box_new();
+	gtk_hbutton_box_set_layout_default(GTK_BUTTONBOX_END);
+	gtk_button_box_set_spacing(GTK_BUTTON_BOX(hbox), 12);
+	but = bf_stock_cancel_button(G_CALLBACK(multi_entry_cancel_clicked), NULL);
+	gtk_box_pack_start(GTK_BOX(hbox),but, FALSE, FALSE, 0);
+	but = bf_stock_ok_button(G_CALLBACK(ok_func), mew);
+	gtk_box_pack_start(GTK_BOX(hbox),but, FALSE, FALSE, 0);
+	gtk_table_attach_defaults(GTK_TABLE(table), hbox, 0, 2, i+1, i+2);
+	gtk_widget_show_all(mew->win);
+}
+#endif
 /**************************************************************************/
 /***********************  BUTTON DIALOG FUNCTIONS  ************************/
 /**************************************************************************/
@@ -798,12 +901,11 @@ void bf_label_tad_with_markup(const gchar *labeltext, gfloat xalign, gfloat yali
 
 /* Emit a delete-event to the appropriate dialog, to detect a user bailing through escape. */
 static gboolean dialog_key_press_event_lcb(GtkWidget *widget,GdkEventKey *event,GtkWidget *dialog) {
-	DEBUG_MSG("widget is %p and dialog is %p", widget, dialog);
-	DEBUG_MSG("dialog_key_press_event_lcb, started\n");
+	DEBUG_MSG("dialog_key_press_event_lcb, started, widget is %p and dialog is %p\n", widget, dialog);
 	if (event->keyval == GDK_Escape) {
 		DEBUG_MSG("dialog_key_press_event_lcb, emit delete_event on %p\n", dialog);
-		g_signal_emit_by_name(G_OBJECT(dialog), "delete_event");
-		DEBUG_MSG("window_full_key_press_event_lcb, emitted delete-event to %p\n", dialog);
+		/* g_signal_emit_by_name(G_OBJECT(dialog), "delete_event"); */
+		gtk_widget_destroy(dialog);
 		return TRUE;
 	}
 	return FALSE;
@@ -825,19 +927,18 @@ static void hig_dialog_backend (GtkDialog *dialog, gchar *primary, gchar *second
 	gchar *spanend = "</span>\n\n";
 	gchar *msgend = "\n";
 	
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
 	vbox = GTK_DIALOG (dialog)->vbox;
-
+	
 	hbox = gtk_hbox_new (FALSE, 12);
-	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), 12);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, FALSE, 0);
 
 	if(icon) {
 		image = gtk_image_new_from_stock (icon , GTK_ICON_SIZE_DIALOG); /* icon unknown ==> "broken image" displayed. */
-		gtk_box_pack_start (GTK_BOX (hbox), image, TRUE, TRUE, 0);
+		gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 		gtk_misc_set_alignment (GTK_MISC (image), 0, 0);
 	}
 
@@ -853,14 +954,14 @@ static void hig_dialog_backend (GtkDialog *dialog, gchar *primary, gchar *second
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.5, 0);
 }
 
 /**
  * multi_button_dialog_backend:
- * @primary #gchar* containing primary dialog message.
- * @secondary #gchar* containing more explanatory message. Set to NULL if unused.
- * @icon #gchar* Your stock GTK image, i.e. GTK_STOCK_DIALOG_WARNING.
+ * @win: #GtkWidget* with the parent window for this dialog
+ * @primary: #gchar* containing primary dialog message.
+ * @secondary: #gchar* containing more explanatory message. Set to NULL if unused.
+ * @icon: #gchar* Your stock GTK image, i.e. GTK_STOCK_DIALOG_WARNING.
  * @defval: #gint default index when user press ENTER.
  * @cancelval: #gint: default index when user press ESCAPE. Should be something non-fatal. If this value is -1, the escape-button will be disabled.
  * @buttons: #gchar** array of buttons. NULL-terminated!! Must contain at least one button.
@@ -869,17 +970,16 @@ static void hig_dialog_backend (GtkDialog *dialog, gchar *primary, gchar *second
  *
  * Return value: #gint the index num of the button label which was clicked	so 0 for the first, 1 for the 2nd etc.
  */
-gint multi_button_dialog_backend(gchar *primary, gchar *secondary, gchar *icon, gint defval, gint cancelval, gchar **buttons)
-{
+gint multi_button_dialog_backend(GtkWidget *win, gchar *primary, gchar *secondary, gchar *icon, gint defval, gint cancelval, gchar **buttons) {
 	GtkWidget *dialog;
 	int i, retval;
 
-	DEBUG_MSG ("multi_button_dialog_backend: Starting. Creating dialog w/button '%s', ID=0\n", *buttons);
 	dialog = gtk_dialog_new_with_buttons (NULL, /* Note that no title is being set. */
-												GTK_WINDOW (main_v->main_window),
+												GTK_WINDOW(win),
 												GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 												*buttons, 0,
 												NULL);
+	DEBUG_MSG ("multi_button_dialog_backend: dialog=%p, primary=%s\n", dialog, primary);
 	/* Add buttons. The index must be correct! */
 	for (i = 1; *++buttons; i++) { /* Walk through the button-list until one reaches NULL. */
 		DEBUG_MSG ("multi_button_dialog_backend: Adding button '%s', ID=%d\n", *buttons, i);
@@ -908,10 +1008,9 @@ gint multi_button_dialog_backend(gchar *primary, gchar *secondary, gchar *icon,
  * 
  * Create and display a single-button message-dialog - HiG-style.
  **/
-void single_button_dialog_backend(gchar * primary, gchar * secondary, gchar * icon)
-{
+void single_button_dialog_backend(GtkWidget *win,gchar * primary, gchar * secondary, gchar * icon) {
 	gchar *buttons[] = {GTK_STOCK_OK, NULL};
-	multi_button_dialog_backend(primary, secondary, icon, 0, 0, buttons);
+	multi_button_dialog_backend(win,primary, secondary, icon, 0, 0, buttons);
 }
 
 /**
@@ -923,9 +1022,8 @@ void single_button_dialog_backend(gchar * primary, gchar * secondary, gchar * ic
  *
  * Return value: void
  */
-void error_dialog(gchar * primary, gchar * secondary)
-{
-	single_button_dialog_backend(primary, secondary, GTK_STOCK_DIALOG_ERROR);
+void error_dialog(GtkWidget *win,gchar * primary, gchar * secondary) {
+	single_button_dialog_backend(win,primary, secondary, GTK_STOCK_DIALOG_ERROR);
 }
 
 /**
@@ -937,9 +1035,8 @@ void error_dialog(gchar * primary, gchar * secondary)
  *
  * Return value: void
  */
-void info_dialog(gchar * primary, gchar * secondary)
-{
-	single_button_dialog_backend(primary, secondary, GTK_STOCK_DIALOG_INFO);
+void info_dialog(GtkWidget *win,gchar * primary, gchar * secondary) {
+	single_button_dialog_backend(win,primary, secondary, GTK_STOCK_DIALOG_INFO);
 }
 
 /**
@@ -951,9 +1048,8 @@ void info_dialog(gchar * primary, gchar * secondary)
  *
  * Return value: void
  */
-void warning_dialog(gchar * primary, gchar * secondary)
-{
-	single_button_dialog_backend(primary, secondary, GTK_STOCK_DIALOG_WARNING);
+void warning_dialog(GtkWidget *win,gchar * primary, gchar * secondary) {
+	single_button_dialog_backend(win,primary, secondary, GTK_STOCK_DIALOG_WARNING);
 }
 
 /* multi_button_dialog and multi_stockbutton_dialog was here */
@@ -970,8 +1066,8 @@ void warning_dialog(gchar * primary, gchar * secondary)
  *
  * Return value: #gint the index num of the button label which was clicked	so 0 for the first, 1 for the 2nd etc.
  */
-gint multi_error_dialog(gchar *primary, gchar *secondary, gint defval, gint cancelval, gchar **buttons) {
-	return multi_button_dialog_backend(primary, secondary, GTK_STOCK_DIALOG_ERROR, defval, cancelval, buttons);
+gint multi_error_dialog(GtkWidget *win,gchar *primary, gchar *secondary, gint defval, gint cancelval, gchar **buttons) {
+	return multi_button_dialog_backend(win,primary, secondary, GTK_STOCK_DIALOG_ERROR, defval, cancelval, buttons);
 }
 
 /**
@@ -986,8 +1082,8 @@ gint multi_error_dialog(gchar *primary, gchar *secondary, gint defval, gint canc
  *
  * Return value: #gint the index num of the button label which was clicked	so 0 for the first, 1 for the 2nd etc.
  */
-gint multi_warning_dialog(gchar *primary, gchar *secondary, gint defval, gint cancelval, gchar **buttons) {
-	return multi_button_dialog_backend(primary, secondary, GTK_STOCK_DIALOG_WARNING, defval, cancelval, buttons);
+gint multi_warning_dialog(GtkWidget *win,gchar *primary, gchar *secondary, gint defval, gint cancelval, gchar **buttons) {
+	return multi_button_dialog_backend(win,primary, secondary, GTK_STOCK_DIALOG_WARNING, defval, cancelval, buttons);
 }
  
 /**
@@ -1002,8 +1098,8 @@ gint multi_warning_dialog(gchar *primary, gchar *secondary, gint defval, gint ca
  *
  * Return value: #gint the index num of the button label which was clicked	so 0 for the first, 1 for the 2nd etc.
  */
-gint multi_query_dialog(gchar *primary, gchar *secondary, gint defval, gint cancelval, gchar **buttons) {
-	return multi_button_dialog_backend(primary, secondary, GTK_STOCK_DIALOG_QUESTION, defval, cancelval, buttons);
+gint multi_query_dialog(GtkWidget *win,gchar *primary, gchar *secondary, gint defval, gint cancelval, gchar **buttons) {
+	return multi_button_dialog_backend(win,primary, secondary, GTK_STOCK_DIALOG_QUESTION, defval, cancelval, buttons);
 }
 
 /************************************************************************/
@@ -1081,8 +1177,7 @@ void progress_set(gpointer gp, guint value)
  *
  * Returns: #gpointer camouflaged pointer to struct Tprogress, a data-structure passed to progress_update.
  **/
-gpointer progress_popup(gchar *title, guint maxvalue)
-{
+gpointer progress_popup(GtkWidget *win,gchar *title, guint maxvalue) {
 	Tprogress *p;
 	
 	p = g_malloc (sizeof (Tprogress));
@@ -1101,7 +1196,7 @@ gpointer progress_popup(gchar *title, guint maxvalue)
 	p->owner = gtk_dialog_new();
 
 	gtk_window_set_modal (GTK_WINDOW (p->owner), TRUE);
-	gtk_window_set_transient_for (GTK_WINDOW (p->owner), GTK_WINDOW (main_v->main_window));
+	gtk_window_set_transient_for (GTK_WINDOW (p->owner), GTK_WINDOW(win));
 
 
 	/* Label, if applicable. Append pretty icon! */
@@ -1121,39 +1216,39 @@ gpointer progress_popup(gchar *title, guint maxvalue)
 /************************ file_but_* FUNCTIONS **************************/
 /************************************************************************/
 
-static void file_but_clicked_lcb(GtkWidget * widget, GtkWidget * which_entry)
-{
-	gchar *tmpstring, *tmp2string;
-	DEBUG_MSG("file_but_clicked_lcb, started, which_entry=%p\n",which_entry);
-	tmpstring = return_file(NULL);
+typedef struct {
+	GtkWidget *entry;
+	Tbfwin *bfwin;
+	gboolean fullpath;
+} Tfilebut;
+
+static void file_but_clicked_lcb(GtkWidget * widget, Tfilebut *fb) {
+	gchar *tmpstring, *tmp2string, *setfile;
+	DEBUG_MSG("file_but_clicked_lcb, started, which_entry=%p\n",fb->entry);
+	setfile = gtk_editable_get_chars(GTK_EDITABLE(GTK_ENTRY(fb->entry)),0,-1);
+	tmpstring = return_file(setfile);
+	g_free(setfile);
 	DEBUG_MSG("file_but_clicked_lcb, return_file returned %s\n",tmpstring);
-	if (tmpstring != NULL) {
-		if (main_v->current_document->filename != NULL) {
-			tmp2string = create_relative_link_to(main_v->current_document->filename, tmpstring);
-		} else {
-			tmp2string = g_path_get_basename(tmpstring);
+	if (tmpstring) {
+		if (!fb->fullpath && fb->bfwin) {
+			if (fb->bfwin->current_document->filename != NULL) {
+				tmp2string = create_relative_link_to(fb->bfwin->current_document->filename, tmpstring);
+			} else {
+				tmp2string = g_path_get_basename(tmpstring);
+			}
+			g_free(tmpstring);
+			tmpstring = tmp2string;
 		}
-		g_free(tmpstring);
-		gtk_entry_set_text(GTK_ENTRY(which_entry), tmp2string);
+		gtk_entry_set_text(GTK_ENTRY(fb->entry), tmpstring);
 /*	perhaps I break something by commenting-out this call, but otherwise the dialog is sometimes started
 	again after the signal is emmitted
-		gtk_signal_emit_by_name(GTK_OBJECT(which_entry), "activate"); */
-		g_free(tmp2string);
+		gtk_signal_emit_by_name(GTK_OBJECT(which_entry), "activate");
+		g_free(tmp2string); */
 	}
 }
 
-static void file_but_clicked_full_lcb(GtkWidget * widget, GtkWidget * which_entry)
-{
-	gchar *tmpstring, *setfile;
-	DEBUG_MSG("file_but_clicked_full_lcb, started, entry=%p\n",which_entry);
-	setfile = gtk_editable_get_chars(GTK_EDITABLE(GTK_ENTRY(which_entry)),0,-1);
-	tmpstring = return_file(setfile);
-	DEBUG_MSG("file_but_clicked_full_lcb, return_file returned %s\n",tmpstring);
-	g_free(setfile);
-	if (tmpstring != NULL) {
-		gtk_entry_set_text(GTK_ENTRY(which_entry), tmpstring);
-		g_free(tmpstring);
-	}
+static void file_but_destroy(GtkObject *object, Tfilebut *fb) {
+	g_free(fb);
 }
 /**
  * file_but_new:
@@ -1165,17 +1260,19 @@ static void file_but_clicked_full_lcb(GtkWidget * widget, GtkWidget * which_entr
  *
  * Return value: #GtkWidget* pointer to file button
  */
-GtkWidget *file_but_new(GtkWidget * which_entry, GtkWidget * win, gint full_pathname) {
+GtkWidget *file_but_new(GtkWidget * which_entry, gint full_pathname, Tbfwin *bfwin) {
 	GtkWidget *file_but;
+	Tfilebut *fb;
 
+	fb = g_new(Tfilebut,1);
+	fb->entry = which_entry;
+	fb->bfwin = bfwin;
+	fb->fullpath = full_pathname;
 	file_but = gtk_button_new();
+	g_signal_connect(G_OBJECT(file_but), "destroy", G_CALLBACK(file_but_destroy), fb);
 	DEBUG_MSG("file_but_new, entry=%p, button=%p\n",which_entry,file_but);
-	gtk_container_add(GTK_CONTAINER(file_but), hbox_with_pix_and_text(_("_Browse..."), 112));
-	if (full_pathname == 1) {
-		g_signal_connect(G_OBJECT(file_but), "clicked", G_CALLBACK(file_but_clicked_full_lcb), which_entry);
-	} else {
-		g_signal_connect(G_OBJECT(file_but), "clicked", G_CALLBACK(file_but_clicked_lcb), which_entry);
-	}
+	gtk_container_add(GTK_CONTAINER(file_but), hbox_with_pix_and_text(_("_Browse..."), 112,TRUE));
+	g_signal_connect(G_OBJECT(file_but), "clicked", G_CALLBACK(file_but_clicked_lcb), fb);
 	gtk_widget_show(file_but);
 	return file_but;
 }
@@ -1240,7 +1337,7 @@ static void fs_ok_clicked_lcb(GtkWidget * widget, Tfileselect *fileselect)
 			&& (g_list_length(fileselect->filenames_to_return) < 1)) 
 		|| (!fileselect->multipleselect 
 			&& strlen(fileselect->filename_to_return) < 1)){
-		statusbar_message(_("No file to insert."), 2000);
+/*		statusbar_message(_("No file to insert."), 2000);*/
 	}
 	
 	g_free(selected_file);	
@@ -1313,10 +1410,9 @@ static void fileselectwin(gchar *setfile, Tfileselect *fileselect, gchar *title)
 	DEBUG_MSG("gtk_widget_fet_parent returns %p\n",gtk_widget_get_parent(fileselect->fs));
 	{
 		GtkWidget *parent = gtk_widget_get_parent(fileselect->fs);
-		if (!parent) {
-			parent = main_v->main_window;
+		if (parent) {
+			gtk_window_set_transient_for(GTK_WINDOW(fileselect->fs), GTK_WINDOW(parent));
 		}
-		gtk_window_set_transient_for(GTK_WINDOW(fileselect->fs), GTK_WINDOW(parent));
 	}
 }
 /**
@@ -1412,3 +1508,82 @@ void destroy_disposable_menu_cb(GtkWidget *widget, GtkWidget *menu) {
 	gtk_widget_destroy(GTK_WIDGET(menu));
 }
 
+
+/***********************************************************************
+ * workarounds for gtk-2.0  
+ * these functions are not needed with gtk-2.2
+ */
+#ifndef HAVE_ATLEAST_GTK_2_2
+static GtkTreePath *gtktreepath_up_multi(GtkTreePath *path, gint num) {
+	while (num > 0) {
+		gtk_tree_path_up(path);
+		num--;
+	}
+	return path;
+}
+
+void gtktreepath_expand_to_root(GtkWidget *tree, const GtkTreePath *this_path) {
+	gint num = gtk_tree_path_get_depth((GtkTreePath *)this_path);
+	while (num >= 0) {
+		GtkTreePath *path = gtk_tree_path_copy(this_path);
+		path = gtktreepath_up_multi(path, num);
+/*		g_signal_handlers_block_matched(G_OBJECT(tree), G_SIGNAL_MATCH_FUNC,
+					0, 0, NULL, row_expanded_lcb, NULL);*/
+		gtk_tree_view_expand_row(GTK_TREE_VIEW(tree), path, FALSE);
+/*		g_signal_handlers_unblock_matched(G_OBJECT(tree), G_SIGNAL_MATCH_FUNC,
+					0, 0, NULL, row_expanded_lcb, NULL);*/
+		gtk_tree_path_free(path);
+		num--;
+	}
+}
+#endif /* ifndef HAVE_ATLEAST_GTK_2_2 */
+
+/*****************************************
+ * workaround for gnome-vfs-2.0
+ * this is copied from gnome-vfs-utils.c
+ * Copyright (C) 1999 Free Software Foundation
+ * Copyright (C) 2000, 2001 Eazel, Inc.
+ */
+#ifdef HAVE_GNOME_VFS
+#ifndef HAVE_ATLEAST_GNOMEVFS_2_2
+#define READ_CHUNK_SIZE 8192
+GnomeVFSResult gnome_vfs_read_entire_file (const char *uri,int *file_size,char **file_contents){
+	GnomeVFSResult result;
+	GnomeVFSHandle *handle;
+	char *buffer;
+	GnomeVFSFileSize total_bytes_read;
+	GnomeVFSFileSize bytes_read;
+	*file_size = 0;
+	*file_contents = NULL;
+	result = gnome_vfs_open (&handle, uri, GNOME_VFS_OPEN_READ);
+	if (result != GNOME_VFS_OK) {
+		return result;
+	}
+	buffer = NULL;
+	total_bytes_read = 0;
+	do {
+		buffer = g_realloc (buffer, total_bytes_read + READ_CHUNK_SIZE);
+		result = gnome_vfs_read (handle,buffer + total_bytes_read,READ_CHUNK_SIZE,&bytes_read);
+		if (result != GNOME_VFS_OK && result != GNOME_VFS_ERROR_EOF) {
+			g_free (buffer);
+			gnome_vfs_close (handle);
+			return result;
+		}
+		if (total_bytes_read + bytes_read < total_bytes_read) {
+			g_free (buffer);
+			gnome_vfs_close (handle);
+			return GNOME_VFS_ERROR_TOO_BIG;
+		}
+		total_bytes_read += bytes_read;
+	} while (result == GNOME_VFS_OK);
+	result = gnome_vfs_close (handle);
+	if (result != GNOME_VFS_OK) {
+		g_free (buffer);
+		return result;
+	}
+	*file_size = total_bytes_read;
+	*file_contents = g_realloc (buffer, total_bytes_read);
+	return GNOME_VFS_OK;
+}			    
+#endif /* ifndef HAVE_ATLEAST_GNOMEVFS_2_2 */
+#endif /* HAVE_GNOME_VFS */
