@@ -405,12 +405,14 @@ static void add_patterns_to_parent(GList **list, gchar *filetype, gchar *name) {
 
 void filetype_highlighting_rebuild() {
 	GList *tmplist;
-
+	GList *alldoclist;
+	
+	alldoclist = return_allwindows_documentlist();
 	/* remove filetypes from documents, but to reconnect them 
 	again after the rebuild, we temporary put a string with 
 	the filetype on that pointer */
-	if (main_v->documentlist) {
-		tmplist = g_list_first(main_v->documentlist);
+	if (alldoclist) {
+		tmplist = g_list_first(alldoclist);
 		while (tmplist) {
 			Tdocument *thisdoc = (Tdocument *)tmplist->data;
 			if (thisdoc->hl) {
@@ -424,25 +426,23 @@ void filetype_highlighting_rebuild() {
 
 	/* first remove the menu widgets, and delete the filetype structs */
 	DEBUG_MSG("filetype_highlighting_rebuild, testing for filetypelist existance\n");
-	if (main_v->filetypelist) {
-		tmplist = g_list_first(main_v->filetypelist);
-		while (tmplist) {
-			Tfiletype *filetype = (Tfiletype *)tmplist->data;
-			filetype_menu_destroy(filetype);
-			g_free(filetype->type);
-			g_strfreev(filetype->extensions);
-			g_free(filetype->update_chars);
-			if (filetype->icon) {
-				g_object_unref(filetype->icon);
-			}
-			g_free(filetype->content_regex);
-			/* the highlightpatterns are freed separately, see below */
-			g_free(filetype);
-			tmplist = g_list_next(tmplist);
+	filetype_menus_empty();
+	tmplist = g_list_first(main_v->filetypelist);
+	while (tmplist) {
+		Tfiletype *filetype = (Tfiletype *)tmplist->data;
+		g_free(filetype->type);
+		g_strfreev(filetype->extensions);
+		g_free(filetype->update_chars);
+		if (filetype->icon) {
+			g_object_unref(filetype->icon);
 		}
-		g_list_free(main_v->filetypelist);
-		main_v->filetypelist = NULL;
+		g_free(filetype->content_regex);
+		/* the highlightpatterns are freed separately, see below */
+		g_free(filetype);
+		tmplist = g_list_next(tmplist);
 	}
+	g_list_free(main_v->filetypelist);
+	main_v->filetypelist = NULL;
 
 	DEBUG_MSG("filetype_highlighting_rebuild, testing for metapattern existence\n");
 	if (highlight.all_highlight_patterns) {
@@ -478,7 +478,6 @@ void filetype_highlighting_rebuild() {
 		arrcount = count_array(strarr);
 		if (arrcount == 6) {
 			filetype = g_new(Tfiletype, 1);
-			filetype->menuitem = NULL;
 			filetype->editable = (strarr[4][0] != '0');
 			filetype->content_regex = g_strdup(strarr[5]);
 			filetype->type = g_strdup(strarr[0]);
@@ -571,8 +570,8 @@ void filetype_highlighting_rebuild() {
 	have to connect all the documents with their filetypes again, we 
 	stored the name of the filetype temporary in the place of the Tfiletype,
 	undo that now */
-	if (main_v->documentlist) {
-		tmplist = g_list_first(main_v->documentlist);
+	if (alldoclist) {
+		tmplist = g_list_first(alldoclist);
 		while (tmplist) {
 			if (((Tdocument *)tmplist->data)->hl) {
 				gchar *tmpstr = (gchar *)((Tdocument *)tmplist->data)->hl;
@@ -584,6 +583,7 @@ void filetype_highlighting_rebuild() {
 			tmplist = g_list_next(tmplist);
 		}
 	}
+	g_list_free(alldoclist);
 }
 
 void hl_init() {
