@@ -1,7 +1,7 @@
 /* Bluefish HTML Editor
  * html_diag.c - general functions to create HTML dialogs
  *
- * Copyright (C) 2000-2001 Olivier Sessink
+ * Copyright (C) 2000-2002 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,11 +17,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-#include "default_include.h"
 
+#include <gtk/gtk.h>
 #include <string.h>	/* strrchr */
 #include <stdlib.h> /* strtod */
-
+/*#define DEBUG*/
 
 #include "bluefish.h"
 #include "html_diag.h" /* myself */
@@ -29,43 +29,83 @@
 #include "bf_lib.h"
 #include "stringlist.h" /* add_to_stringlist */
 #include "document.h" /* doc_save_selection */
+#include "cap.h"
 
+Trecent_attribs recent_attribs;
 /*****************************************/
 /********** DIALOG FUNCTIONS *************/
 /*****************************************/
 
-void html_diag_destroy_cb(GtkWidget * widget, GdkEvent *event,  Thtml_diag *dg) {
-	dg->doc->saved_sel.saved = FALSE;
+void html_diag_destroy_cb(GtkWidget * widget, Thtml_diag *dg) {
+	DEBUG_MSG("html_diag_destroy_cb, widget=%p, dg=%p, dg->dialog=%p\n",widget,dg,dg->dialog);
+	if (dg->mark_ins) {
+		gtk_text_buffer_delete_mark(dg->doc->buffer,dg->mark_ins);
+		gtk_text_buffer_delete_mark(dg->doc->buffer,dg->mark_sel);
+	}
 	window_destroy(dg->dialog);
+	DEBUG_MSG("html_diag_destroy_cb, about to free dg=%p\n",dg);
 	g_free(dg);
 }
 
 void html_diag_cancel_clicked_cb(GtkWidget *widget, gpointer data) {
-	html_diag_destroy_cb(NULL, NULL, data);
+	html_diag_destroy_cb(NULL, data);
 }
 
-Thtml_diag *html_diag_new(gchar *title) {
+Thtml_diag *html_diag_new(Tbfwin *bfwin, gchar *title) {
 	Thtml_diag *dg;
 	
 	dg = g_malloc(sizeof(Thtml_diag));
+	DEBUG_MSG("html_diag_new, dg=%p\n",dg);
 	dg->dialog = window_full(title, GTK_WIN_POS_MOUSE
-		, GTK_WINDOW_DIALOG, 5,html_diag_destroy_cb , dg);
-	gtk_window_set_wmclass(GTK_WINDOW(dg->dialog), "Bluefish", "html_dialog");
+		, 12,G_CALLBACK(html_diag_destroy_cb), dg, TRUE);
+	gtk_window_set_type_hint(GTK_WINDOW(dg->dialog), GDK_WINDOW_TYPE_HINT_DIALOG);
+
+	gtk_window_set_role(GTK_WINDOW(dg->dialog), "html_dialog");
 	dg->vbox = gtk_vbox_new(FALSE, 1);
 	gtk_container_add(GTK_CONTAINER(dg->dialog), dg->vbox);
-
+#ifdef DEBUG
+	{
+		Tdocument *doc = bfwin->current_document;
+		GtkTextIter iter1, iter2;
+		GtkTextMark* mark;
+		mark = gtk_text_buffer_get_mark(doc->buffer,"insert");
+		gtk_text_buffer_get_iter_at_mark(doc->buffer,&iter1,mark);
+		mark = gtk_text_buffer_get_mark(doc->buffer,"selection_bound");
+		gtk_text_buffer_get_iter_at_mark(doc->buffer,&iter2,mark);
+		g_print("html_diag_new, current marks: insert=%d, selection=%d\n",gtk_text_iter_get_offset(&iter1),gtk_text_iter_get_offset(&iter2));
+	}
+#endif
+	{
+		if (!gtk_text_buffer_get_mark(bfwin->current_document->buffer,"diag_ins")) {
+			GtkTextIter iter;
+			GtkTextMark* mark = gtk_text_buffer_get_mark(bfwin->current_document->buffer,"insert");
+			gtk_text_buffer_get_iter_at_mark(bfwin->current_document->buffer,&iter,mark);
+			dg->mark_ins = gtk_text_buffer_create_mark(bfwin->current_document->buffer,"diag_ins",&iter,TRUE);
+			mark = gtk_text_buffer_get_mark(bfwin->current_document->buffer,"selection_bound");
+			gtk_text_buffer_get_iter_at_mark(bfwin->current_document->buffer,&iter,mark);
+			dg->mark_sel = gtk_text_buffer_create_mark(bfwin->current_document->buffer,"diag_sel",&iter,TRUE);
+		} else {
+			dg->mark_ins = dg->mark_sel = NULL;
+		}
+	}
 	dg->range.pos = -1;
-	dg->range.len = -1;
+	dg->range.end = -1;
+	if (main_v->props.transient_htdialogs) {
+		/* must be set before realizing */
+		DEBUG_MSG("html_diag_finish, setting dg->dialog=%p transient!\n", dg->dialog);
+		gtk_window_set_transient_for(GTK_WINDOW(dg->dialog), GTK_WINDOW(bfwin->main_window));
+	}
 
 	gtk_widget_realize(dg->dialog);
-	dg->doc = main_v->current_document;
+	dg->bfwin = bfwin;
+	dg->doc = bfwin->current_document;
 	return dg;
 }
 
 GtkWidget *html_diag_table_in_vbox(Thtml_diag *dg, gint rows, gint cols) {
-	GtkWidget *returnwidget = gtk_table_new(rows, cols, 0);
-	gtk_table_set_row_spacings(GTK_TABLE(returnwidget), 4);
-	gtk_table_set_col_spacings(GTK_TABLE(returnwidget), 4);
+	GtkWidget *returnwidget = gtk_table_new(rows, cols, FALSE);
+	gtk_table_set_row_spacings(GTK_TABLE(returnwidget), 12);
+	gtk_table_set_col_spacings(GTK_TABLE(returnwidget), 12);
 	gtk_box_pack_start(GTK_BOX(dg->vbox), returnwidget, FALSE, FALSE, 0);
 	return returnwidget;
 }
@@ -73,25 +113,20 @@ GtkWidget *html_diag_table_in_vbox(Thtml_diag *dg, gint rows, gint cols) {
 void html_diag_finish(Thtml_diag *dg, GtkSignalFunc ok_func) {
 	GtkWidget *hbox;
 
-	doc_save_selection(main_v->current_document);
-
+	gtk_box_pack_start(GTK_BOX(dg->vbox), gtk_hseparator_new(), FALSE, FALSE, 12);
 	hbox = gtk_hbutton_box_new();
 	gtk_hbutton_box_set_layout_default(GTK_BUTTONBOX_END);
-	gtk_button_box_set_spacing(GTK_BUTTON_BOX(hbox), 1);
+	gtk_button_box_set_spacing(GTK_BUTTON_BOX(hbox), 12);
 	
 	dg->obut = bf_stock_ok_button(ok_func, dg);
-	dg->cbut = bf_stock_cancel_button(html_diag_cancel_clicked_cb, dg);
+	dg->cbut = bf_stock_cancel_button(G_CALLBACK(html_diag_cancel_clicked_cb), dg);
 
+	gtk_box_pack_start(GTK_BOX(hbox),dg->cbut , FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox),dg->obut , FALSE, FALSE, 0);
 	gtk_window_set_default(GTK_WINDOW(dg->dialog), dg->obut);
-	gtk_box_pack_start(GTK_BOX(hbox),dg->cbut , FALSE, FALSE, 0);
 
 	gtk_box_pack_start(GTK_BOX(dg->vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show_all(GTK_WIDGET(dg->dialog));
-	if (main_v->props.transient_htdialogs) {
-		DEBUG_MSG("html_diag_finish, setting transient!\n");
-		gtk_window_set_transient_for(GTK_WINDOW(dg->dialog), GTK_WINDOW(main_v->main_window));
-	}
 }
 
 /*************************************************/
@@ -135,8 +170,7 @@ void parse_html_for_dialogvalues(gchar *dialogitems[], gchar *dialogvalues[]
 }
 
 void fill_dialogvalues(gchar *dialogitems[], gchar *dialogvalues[]
-		, gchar **custom, Ttagpopup *data, GtkWidget *sending_widget
-		, Thtml_diag *diag) {
+		, gchar **custom, Ttagpopup *data, Thtml_diag *diag) {
 
 	gint count=0;
 	
@@ -149,14 +183,14 @@ void fill_dialogvalues(gchar *dialogitems[], gchar *dialogvalues[]
 	 * is called by the right-click-opup, so data will contain info about
 	 * the position of the tag */
 
-	if (data && !sending_widget) {
+	if (data) {
 		parse_html_for_dialogvalues(dialogitems, dialogvalues, custom, data);
 		diag->range.pos = data->pos;
-		diag->range.len = data->len;
+		diag->range.end = data->end;
 	} else {
 		DEBUG_MSG("fill_dialogvalues, no data, or a sending widget\n");
 		diag->range.pos = -1;
-		diag->range.len = -1;
+		diag->range.end = -1;
 	}
 }
 
@@ -276,7 +310,7 @@ gchar *insert_integer_if_spin(GtkWidget * spin, gchar * itemname, gchar * string
 
 	gchar *tempstring;
 
-	if (strlen(gtk_entry_get_text(GTK_ENTRY(spin)))) {
+	if (strcmp(itemname, cap("BORDER")) == 0 || strcmp(gtk_entry_get_text(GTK_ENTRY(spin)), "0") != 0) {
 		if ((percentage) && (GTK_TOGGLE_BUTTON(percentage)->active)) {
 			tempstring = g_strdup_printf("%s %s=\"%d%%\"", string2add2, itemname, gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin)));
 		} else {
