@@ -90,8 +90,8 @@ GtkWidget *php_var_but(GtkWidget *src, GtkWidget *dest, Thtml_diag *dg, gint typ
 /************************************************************************/
 /************************************************************************/
 
-static void formok_lcb(GtkWidget * widget, Thtml_diag *dg)
-{
+static void formok_lcb(GtkWidget * widget, Thtml_diag *dg) {
+	Tbfwin *bfwin = dg->bfwin;
 	gchar *thestring, *finalstring;
 
 	thestring = g_strdup(cap("<FORM"));
@@ -103,7 +103,7 @@ static void formok_lcb(GtkWidget * widget, Thtml_diag *dg)
 	finalstring = g_strconcat(thestring, ">", NULL);
 	g_free(thestring);
 
-	recent_attribs.targetlist = add_entry_to_stringlist(recent_attribs.targetlist, GTK_WIDGET(GTK_COMBO(dg->combo[3])->entry));
+	bfwin->session->targetlist = add_entry_to_stringlist(bfwin->session->targetlist, GTK_WIDGET(GTK_COMBO(dg->combo[3])->entry));
 	if (dg->range.end == -1) {
 		doc_insert_two_strings(dg->doc, finalstring, cap("</FORM>"));
 	} else {
@@ -115,8 +115,7 @@ static void formok_lcb(GtkWidget * widget, Thtml_diag *dg)
 }
 
 
-void formdialog_cb(GtkWidget * widget, gpointer data)
-{
+void formdialog_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	GList *methodlist = NULL;
 	GList *enctypelist = NULL;
 
@@ -126,17 +125,17 @@ void formdialog_cb(GtkWidget * widget, gpointer data)
 	Thtml_diag *dg;
 	GtkWidget *dgtable;
 
-	dg = html_diag_new(_("Form"));
-	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, widget, dg);
+	dg = html_diag_new(bfwin,_("Form"));
+	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, dg);
 
 	dgtable = html_diag_table_in_vbox(dg, 4, 10);
 
-	recent_attribs.urllist = add_to_stringlist(recent_attribs.urllist, "<?php echo $SCRIPT_NAME ?>");
-	recent_attribs.urllist = add_to_stringlist(recent_attribs.urllist, "'.$SCRIPT_NAME.'");
+	bfwin->session->urllist = add_to_stringlist(bfwin->session->urllist, "<?php echo $SCRIPT_NAME ?>");
+	bfwin->session->urllist = add_to_stringlist(bfwin->session->urllist, "'.$SCRIPT_NAME.'");
 	{
 	GList *rel_link_list, *tmplist;
 	rel_link_list = NULL /*generate_relative_doc_list()*/;
-	tmplist = duplicate_stringlist(recent_attribs.urllist, 1);
+	tmplist = duplicate_stringlist(bfwin->session->urllist, 1);
 	rel_link_list = g_list_concat(tmplist, rel_link_list);
 
 	dg->combo[4] = combo_with_popdown(tagvalues[0], rel_link_list, 1);
@@ -146,7 +145,7 @@ void formdialog_cb(GtkWidget * widget, gpointer data)
 	
 	bf_mnemonic_label_tad_with_alignment(_("_Action:"), dg->combo[4], 0, 0.5, dgtable, 0, 1, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->combo[4], 1, 8, 0, 1);
-	gtk_table_attach_defaults(GTK_TABLE(dgtable), file_but_new(GTK_WIDGET(GTK_COMBO(dg->combo[4])->entry), dg->dialog, 0), 8, 10, 0, 1);
+	gtk_table_attach_defaults(GTK_TABLE(dgtable), file_but_new(GTK_WIDGET(GTK_COMBO(dg->combo[4])->entry), 0, bfwin), 8, 10, 0, 1);
 	
 	methodlist = g_list_append(methodlist, "GET");
 	methodlist = g_list_append(methodlist, "POST");
@@ -164,10 +163,10 @@ void formdialog_cb(GtkWidget * widget, gpointer data)
 	bf_mnemonic_label_tad_with_alignment(_("_Enctype:"), dg->combo[2], 0, 0.5, dgtable, 3, 4, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(dg->combo[2]), 4, 10, 1, 2);
 
-	recent_attribs.targetlist = add_to_stringlist(recent_attribs.targetlist, "_top");
-	recent_attribs.targetlist = add_to_stringlist(recent_attribs.targetlist, "_blank");
-	recent_attribs.targetlist = add_to_stringlist(recent_attribs.targetlist, "_parent");
-	dg->combo[3] = combo_with_popdown(tagvalues[3], recent_attribs.targetlist, 1);
+	bfwin->session->targetlist = add_to_stringlist(bfwin->session->targetlist, "_top");
+	bfwin->session->targetlist = add_to_stringlist(bfwin->session->targetlist, "_blank");
+	bfwin->session->targetlist = add_to_stringlist(bfwin->session->targetlist, "_parent");
+	dg->combo[3] = combo_with_popdown(tagvalues[3], bfwin->session->targetlist, 1);
 	bf_mnemonic_label_tad_with_alignment(_("_Target:"), dg->combo[3], 0, 0.5, dgtable, 0, 1, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(GTK_COMBO(dg->combo[3])), 1, 10, 2, 3);
 
@@ -203,16 +202,15 @@ static void textareaok_lcb(GtkWidget * widget, Thtml_diag *dg)
 	html_diag_destroy_cb(NULL, dg);
 }
 
-void textareadialog_cb(GtkWidget * widget, gpointer data)
-{
+void textareadialog_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	static gchar *tagitems[] = { "name", "value", "rows", "cols", NULL };
 	gchar *tagvalues[5];
 	gchar *custom = NULL;
 	GtkWidget *dgtable;
 	Thtml_diag *dg;
 
-	dg = html_diag_new(_("Text area"));
-	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, widget, dg);
+	dg = html_diag_new(bfwin,_("Text area"));
+	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, dg);
 
 	dgtable = html_diag_table_in_vbox(dg, 4, 10);
 
@@ -264,8 +262,7 @@ static void textok_lcb(GtkWidget * widget, Thtml_diag *dg)
 }
 
 
-void textdialog_cb(GtkWidget * widget, gpointer data)
-{
+void textdialog_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	GtkWidget *varbut;
 	static gchar *tagitems[] = { "name", "value", "size", "maxlength", "type", NULL };
 	gchar *tagvalues[6];
@@ -273,8 +270,8 @@ void textdialog_cb(GtkWidget * widget, gpointer data)
 	GtkWidget *dgtable;
 	Thtml_diag *dg;
 
-	dg = html_diag_new(_("Text"));
-	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, widget, dg);
+	dg = html_diag_new(bfwin,_("Text"));
+	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, dg);
 
 	dgtable = html_diag_table_in_vbox(dg, 5, 10);
 
@@ -332,7 +329,7 @@ static void buttondialogok_lcb(GtkWidget * widget, Thtml_diag *dg)
 	html_diag_destroy_cb(NULL, dg);
 }
 
-void buttondialog_cb(GtkWidget * widget, gpointer data) {
+void buttondialog_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	static gchar *tagitems[] = { "name", "value", "type",  NULL };
 	gchar *tagvalues[4];
 	gchar *custom = NULL;
@@ -340,8 +337,8 @@ void buttondialog_cb(GtkWidget * widget, gpointer data) {
 	Thtml_diag *dg;
 	GList *tmplist=NULL;
 
-	dg = html_diag_new(_("Button"));
-	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, widget, dg);
+	dg = html_diag_new(bfwin,_("Button"));
+	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, dg);
 
 	dgtable = html_diag_table_in_vbox(dg, 5, 10);
 
@@ -394,8 +391,7 @@ static void hiddenok_lcb(GtkWidget * widget, Thtml_diag *dg)
 }
 
 
-void hiddendialog_cb(GtkWidget * widget, gpointer data)
-{
+void hiddendialog_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	static gchar *tagitems[] = { "name", "value", "type", NULL };
 	gchar *tagvalues[4];
 	gchar *custom = NULL;
@@ -403,8 +399,8 @@ void hiddendialog_cb(GtkWidget * widget, gpointer data)
 	GtkWidget *dgtable;
 	Thtml_diag *dg;
 
-	dg = html_diag_new(_("Hidden"));
-	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, widget, dg);
+	dg = html_diag_new(bfwin,_("Hidden"));
+	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, dg);
 
 	dgtable = html_diag_table_in_vbox(dg, 5, 10);
 	dg->entry[1] = entry_with_text(tagvalues[0], 256);
@@ -450,8 +446,7 @@ static void radiodialogok_lcb(GtkWidget * widget, Thtml_diag *dg)
 }
 
 
-void radiodialog_cb(GtkWidget * widget, gpointer data)
-{
+void radiodialog_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	static gchar *tagitems[] = { "name", "value", "checked", "type", NULL };
 	gchar *tagvalues[5];
 	gchar *custom = NULL;
@@ -459,8 +454,8 @@ void radiodialog_cb(GtkWidget * widget, gpointer data)
 	GtkWidget *dgtable, *varbut;
 	Thtml_diag *dg;
 
-	dg = html_diag_new(_("Radio Button"));
-	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, widget, dg);
+	dg = html_diag_new(bfwin,_("Radio Button"));
+	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, dg);
 
 	dgtable = html_diag_table_in_vbox(dg, 5, 10);
 	dg->entry[1] = entry_with_text(tagvalues[0], 256);
@@ -513,16 +508,15 @@ static void checkdialogok_lcb(GtkWidget * widget,Thtml_diag *dg )
 	html_diag_destroy_cb(NULL, dg);
 }
 
-void checkdialog_cb(GtkWidget * widget, gpointer data)
-{
+void checkdialog_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	static gchar *tagitems[] = { "name", "value", "checked", "type", NULL };
 	gchar *tagvalues[5];
 	gchar *custom = NULL;
 	GtkWidget *dgtable, *varbut;
 	Thtml_diag *dg;
 
-	dg = html_diag_new(_("Check Box"));
-	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, widget, dg);
+	dg = html_diag_new(bfwin,_("Check Box"));
+	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, dg);
 
 	dgtable = html_diag_table_in_vbox(dg, 5, 10);
 	
@@ -572,16 +566,15 @@ static void selectdialogok_lcb(GtkWidget * widget, Thtml_diag *dg)
 	html_diag_destroy_cb(NULL, dg);
 }
 
-void selectdialog_cb(GtkWidget * widget, gpointer data)
-{
+void selectdialog_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	static gchar *tagitems[] = { "name", "size", "multiple", NULL };
 	gchar *tagvalues[4];
 	gchar *custom = NULL;
 	GtkWidget *dgtable;
 	Thtml_diag *dg;
 
-	dg = html_diag_new(_("Select"));
-	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, widget, dg);
+	dg = html_diag_new(bfwin,_("Select"));
+	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, dg);
 
 	dgtable = html_diag_table_in_vbox(dg, 5, 10);
 
@@ -627,16 +620,15 @@ static void optiondialogok_lcb(GtkWidget * widget,Thtml_diag *dg )
 	html_diag_destroy_cb(NULL, dg);
 }
 
-void optiondialog_cb(GtkWidget * widget, gpointer data)
-{
+void optiondialog_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	static gchar *tagitems[] = { "value", "label", "selected", NULL };
 	gchar *tagvalues[4];
 	gchar *custom = NULL;
 	GtkWidget *dgtable;
 	Thtml_diag *dg;
 
-	dg = html_diag_new(_("Option"));
-	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, widget, dg);
+	dg = html_diag_new(bfwin,_("Option"));
+	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, dg);
 
 	dgtable = html_diag_table_in_vbox(dg, 3, 10);
 
@@ -676,16 +668,15 @@ static void optgroupdialogok_lcb(GtkWidget * widget,Thtml_diag *dg )
 	html_diag_destroy_cb(NULL, dg);
 }
 
-void optgroupdialog_cb(GtkWidget * widget, gpointer data)
-{
+void optgroupdialog_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	static gchar *tagitems[] = { "label", NULL };
 	gchar *tagvalues[2];
 	gchar *custom = NULL;
 	GtkWidget *dgtable;
 	Thtml_diag *dg;
 
-	dg = html_diag_new(_("Option group"));
-	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, widget, dg);
+	dg = html_diag_new(bfwin,_("Option group"));
+	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, dg);
 
 	dgtable = html_diag_table_in_vbox(dg, 5, 10);
 	dg->entry[1] = entry_with_text(tagvalues[0], 256);
