@@ -67,8 +67,7 @@ static void tabledialogok_lcb(GtkWidget * widget, Thtml_diag * dg)
 }
 
 
-void tabledialog_cb(GtkWidget * widget, gpointer data)
-{
+void tabledialog_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	GList *alignlist = NULL, *popuplist;
 	GtkWidget *var_but, *dgtable;
 
@@ -79,8 +78,8 @@ void tabledialog_cb(GtkWidget * widget, gpointer data)
 	gchar *custom = NULL;
 	Thtml_diag *dg;
 
-	dg = html_diag_new(_("Table"));
-	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, widget, dg);
+	dg = html_diag_new(bfwin,_("Table"));
+	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, dg);
 
 	dgtable = html_diag_table_in_vbox(dg, 5, 8);
 
@@ -92,7 +91,7 @@ void tabledialog_cb(GtkWidget * widget, gpointer data)
 	bf_mnemonic_label_tad_with_alignment(_("C_ell Spacing:"), dg->spin[3], 0, 0.5, dgtable, 0, 1, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->spin[3], 1, 2, 1, 2);
 
-	dg->combo[4] = combo_with_popdown_sized(tagvalues[7], recent_attribs.classlist, 1, 80);
+	dg->combo[4] = combo_with_popdown_sized(tagvalues[7], bfwin->session->classlist, 1, 80);
 	bf_mnemonic_label_tad_with_alignment(_("Cl_ass:"), dg->combo[4], 0, 0.5, dgtable, 0, 1, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->combo[4], 1, 2, 2, 3);
 
@@ -128,7 +127,7 @@ void tabledialog_cb(GtkWidget * widget, gpointer data)
 	bf_mnemonic_label_tad_with_alignment(_("_Valign:"), dg->combo[2], 1, 0.5, dgtable, 2, 3, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->combo[2], 3, 5, 1, 2);
 
-	dg->combo[3] = combo_with_popdown_sized(tagvalues[5], recent_attribs.colorlist, 1, 80);
+	dg->combo[3] = combo_with_popdown_sized(tagvalues[5], bfwin->session->colorlist, 1, 80);
 	var_but = color_but_new(GTK_COMBO(dg->combo[3])->entry, dg->dialog);
 	bf_mnemonic_label_tad_with_alignment(_("Backgrou_nd Color:"), dg->combo[3], 0, 0.5, dgtable, 2, 3, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->combo[3], 3, 4, 2, 3);
@@ -201,8 +200,7 @@ static void tablerowdialogok_lcb(GtkWidget * widget, Thtml_diag *dg)
 }
 
 
-void tablerowdialog_cb(GtkWidget * widget, gpointer data)
-{
+void tablerowdialog_dialog(Tbfwin *bfwin, Ttagpopup *data) {
 	GList *alignlist = NULL;
 	GtkWidget *color_but, *var_but;
 
@@ -212,8 +210,8 @@ void tablerowdialog_cb(GtkWidget * widget, gpointer data)
 	Thtml_diag *dg;
 	GtkWidget *dgtable;
 
-	dg = html_diag_new(_("Table Row"));
-	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, widget, dg);
+	dg = html_diag_new(bfwin,_("Table Row"));
+	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, dg);
 
 	dgtable = html_diag_table_in_vbox(dg, 4, 5);
 
@@ -239,11 +237,11 @@ void tablerowdialog_cb(GtkWidget * widget, gpointer data)
 	bf_mnemonic_label_tad_with_alignment(_("_Valign:"), dg->combo[2], 0, 0.5, dgtable, 0, 1, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(GTK_COMBO(dg->combo[2])), 1, 2, 1, 2);
 
-	dg->combo[4] = combo_with_popdown_sized(tagvalues[3], recent_attribs.classlist, 1, 90);
+	dg->combo[4] = combo_with_popdown_sized(tagvalues[3], bfwin->session->classlist, 1, 90);
 	bf_mnemonic_label_tad_with_alignment(_("Cl_ass:"), dg->combo[4], 1, 0.5, dgtable, 2, 3, 0, 1);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->combo[4], 3, 5, 0, 1);
 
-	dg->combo[3] = combo_with_popdown_sized(tagvalues[2], recent_attribs.colorlist, 1, 90);
+	dg->combo[3] = combo_with_popdown_sized(tagvalues[2], bfwin->session->colorlist, 1, 90);
 	color_but = color_but_new(GTK_COMBO(dg->combo[3])->entry, dg->dialog);
 	bf_mnemonic_label_tad_with_alignment(_("Backgrou_nd Color:"), dg->combo[3], 0, 0.5, dgtable, 2, 3, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(GTK_COMBO(dg->combo[3])), 3, 4, 1, 2);
@@ -308,7 +306,7 @@ static void tableheaddialogok_lcb(GtkWidget * widget, Thtml_diag *dg) {
 	table_head_and_data_dialogok_lcb(0, widget, dg);
 }
 
-static void table_head_and_data_dialog_cb(gint type, GtkWidget * widget, gpointer data) {
+static void table_head_and_data_dialog_cb(gint type, Tbfwin *bfwin, Ttagpopup *data) {
 	GList *alignlist = NULL;
 
 	static gchar *tagitems[] = { "width", "align", "colspan"
@@ -321,12 +319,12 @@ static void table_head_and_data_dialog_cb(gint type, GtkWidget * widget, gpointe
 	GtkWidget *dgtable, *var_but;
 
 	if (type == 1) {
-		dg = html_diag_new(_("Table Data"));
+		dg = html_diag_new(bfwin, _("Table Data"));
 	} else {
-		dg = html_diag_new(_("Table Header"));
+		dg = html_diag_new(bfwin,_("Table Header"));
 	}
 	
-	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, widget, dg);
+	fill_dialogvalues(tagitems, tagvalues, &custom, (Ttagpopup *) data, dg);
 
 	dgtable = html_diag_table_in_vbox(dg, 5, 7);
 
@@ -353,7 +351,7 @@ static void table_head_and_data_dialog_cb(gint type, GtkWidget * widget, gpointe
 	bf_mnemonic_label_tad_with_alignment(_("_Valign:"), dg->combo[2], 0, 0.5, dgtable, 0, 1, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(GTK_COMBO(dg->combo[2])), 1, 2, 1, 2);
 
-	dg->combo[4] = combo_with_popdown_sized(tagvalues[8], recent_attribs.classlist, 1, 80);
+	dg->combo[4] = combo_with_popdown_sized(tagvalues[8], bfwin->session->classlist, 1, 80);
 	bf_mnemonic_label_tad_with_alignment(_("Cl_ass:"), dg->combo[4], 0, 0.5, dgtable, 0, 1, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(GTK_COMBO(dg->combo[4])), 1, 2, 2, 3);
 
@@ -394,7 +392,7 @@ static void table_head_and_data_dialog_cb(gint type, GtkWidget * widget, gpointe
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->spin[3], 5, 6, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), dg->check[3], 6, 7, 1, 2);
 
-	dg->combo[3] = combo_with_popdown_sized(tagvalues[6], recent_attribs.colorlist, 1, 80);
+	dg->combo[3] = combo_with_popdown_sized(tagvalues[6], bfwin->session->colorlist, 1, 80);
 	bf_mnemonic_label_tad_with_alignment(_("Backgrou_nd Color:"), dg->combo[3], 1, 0.5, dgtable, 4, 5, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(GTK_COMBO(dg->combo[3])), 5, 6, 2, 3);
 	gtk_table_attach_defaults(GTK_TABLE(dgtable), GTK_WIDGET(color_but_new(GTK_COMBO(dg->combo[3])->entry, dg->dialog)), 6, 7, 2, 3);
@@ -408,10 +406,10 @@ static void table_head_and_data_dialog_cb(gint type, GtkWidget * widget, gpointe
 	if (custom)	g_free(custom);
 }
 
-void tabledatadialog_cb(GtkWidget * widget, gpointer data) {
-	table_head_and_data_dialog_cb(1, widget, data);
+void tabledatadialog_dialog(Tbfwin *bfwin, Ttagpopup *data) {
+	table_head_and_data_dialog_cb(1, bfwin, data);
 }
 
-void tableheaddialog_cb(GtkWidget * widget, gpointer data) {
-	table_head_and_data_dialog_cb(0, widget, data);
+void tableheaddialog_dialog(Tbfwin *bfwin, Ttagpopup *data) {
+	table_head_and_data_dialog_cb(0, bfwin, data);
 }
