@@ -1,7 +1,7 @@
 /* Bluefish HTML Editor
- * project.h - this file contains the project and project edit code
+ * project.h - project prototypes
  *
- * Copyright (C) 2000 Olivier Sessink
+ * Copyright (C) 2003 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,14 +17,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
 #ifndef __PROJECT_H_
-#define __PROJECT_H_
-void project_add_document_cb(GtkWidget * widget, gpointer data);
-void project_edit_cb(GtkWidget * widget, gpointer data);
-void project_open_cb(GtkWidget * widget, gpointer data);
-void project_close_cb(GtkWidget * widget, gpointer data);
-void project_save_cb(GtkWidget * widget, gpointer data);
-void project_save_as_cb(GtkWidget * widget, gpointer data);
-void project_from_file(void);
-#endif /* __PROJECT_H_ */
+#define __PROJECT_H_ 
+
+/* #define DEBUG */
+gboolean project_save_and_close(Tbfwin *bfwin);
+void project_open_from_file(Tbfwin *bfwin, gchar *fromfilename);
+void set_project_menu_widgets(Tbfwin *bfwin, gboolean win_has_project);
+void project_menu_cb(Tbfwin *bfwin,guint callback_action, GtkWidget *widget);
+
+#endif /* __PROJECT_H_  */
