@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-/* #define DEBUG */
+/*#define DEBUG*/
 
 #include <gtk/gtk.h>
 #include <sys/stat.h>
@@ -75,37 +75,43 @@ GList *make_config_list_item(GList * config_list, void *pointer_to_var, unsigned
 	return (GList *) g_list_append(config_list, config_list_item);
 }
 
-static void init_prop_integer(GList ** config_list, void *pointer_to_var, gchar * name_of_var, gint default_value)
+static void init_prop_integer(GList ** config_list, void *pointer_to_var, gchar * name_of_var, gint default_value, gboolean set_default)
 {
 	*config_list = make_config_list_item(*config_list, pointer_to_var, 'i', name_of_var, 0);
-	*(gint *) pointer_to_var = default_value;
+	if (set_default) *(gint *)pointer_to_var = default_value;
 }
 
-static void init_prop_string(GList ** config_list, void *pointer_to_var, gchar * name_of_var, gchar * default_value)
+static void init_prop_string(GList ** config_list, void *pointer_to_var, gchar * name_of_var, const gchar * default_value)
 {
 	*config_list = make_config_list_item(*config_list, pointer_to_var, 's', name_of_var, 0);
-	*(gchar **) pointer_to_var = g_strdup(default_value);
-	DEBUG_MSG("init_prop_string, name_of_var=%s, default_value=%s\n", name_of_var, default_value);
+	if (*(gchar **) pointer_to_var == NULL) {
+		*(gchar **) pointer_to_var = g_strdup(default_value);
+	}
+	DEBUG_MSG("init_prop_string, name_of_var=%s, default_value=%s, current value=%s\n", name_of_var, default_value, *(gchar **) pointer_to_var);
 }
 
 static void init_prop_string_with_escape(GList ** config_list, void *pointer_to_var, gchar * name_of_var, gchar * default_value)
 {
 	*config_list = make_config_list_item(*config_list, pointer_to_var, 'e', name_of_var, 0);
-	*(gchar **) pointer_to_var = unescapestring(default_value);
+	*(gchar **) pointer_to_var = unescape_string(default_value, FALSE);
 	DEBUG_MSG("init_prop_string, name_of_var=%s, default_value=%s\n", name_of_var, default_value);
 }
 
-static void init_prop_stringlist(GList ** config_list, void *pointer_to_var, gchar * name_of_var)
+static void init_prop_stringlist(GList ** config_list, void *pointer_to_var, gchar * name_of_var, gboolean setNULL)
 {
 	*config_list = make_config_list_item(*config_list, pointer_to_var, 'l', name_of_var, 0);
-	pointer_to_var = NULL;
+	if (setNULL) {
+	 	pointer_to_var = NULL;
+	}
 }
 
 
-static void init_prop_arraylist(GList ** config_list, void *pointer_to_var, gchar * name_of_var, gint len)
+static void init_prop_arraylist(GList ** config_list, void *pointer_to_var, gchar * name_of_var, gint len, gboolean setNULL)
 {
 	*config_list = make_config_list_item(*config_list, pointer_to_var, 'a', name_of_var, len);
-	pointer_to_var = NULL;
+	if (setNULL) {
+	 	pointer_to_var = NULL;
+	}
 }
 
 static gint save_config_file(GList * config_list, gchar * filename)
@@ -150,7 +156,7 @@ static gint save_config_file(GList * config_list, gchar * filename)
 			DEBUG_MSG("save_config_file, converting \"%p\"\n", tmpitem);
 			DEBUG_MSG("save_config_file, converting \"%s %s\"\n", tmpitem->identifier, (gchar *) * (void **) tmpitem->pointer);
 			if (*(void **) tmpitem->pointer) {
-				tmpstring2 = escapestring((gchar*)*(void**)tmpitem->pointer, '\0');
+				tmpstring2 = escape_string((gchar*)*(void**)tmpitem->pointer, FALSE);
 				tmpstring = g_strdup_printf("%s %s", tmpitem->identifier, tmpstring2);
 
 				DEBUG_MSG("save_config_file, adding %s\n", tmpstring);
@@ -178,7 +184,7 @@ static gint save_config_file(GList * config_list, gchar * filename)
 			tmplist2 = g_list_last((GList *) * (void **) tmpitem->pointer);
 			DEBUG_MSG("save_config_file, the tmplist2(%p)\n", tmplist2);
 			while (tmplist2 != NULL) {
-				tmpstring2 = array_to_string((char **) tmplist2->data, ':');
+				tmpstring2 = array_to_string((char **) tmplist2->data);
 				tmpstring = g_strdup_printf("%s %s", tmpitem->identifier, tmpstring2);
 				DEBUG_MSG("save_config_file, tmpstring(%p)=%s\n", tmpstring, tmpstring);
 				rclist = g_list_append(rclist, tmpstring);
@@ -200,6 +206,7 @@ static gint save_config_file(GList * config_list, gchar * filename)
 
 static gboolean parse_config_file(GList * config_list, gchar * filename)
 {
+	gboolean retval = FALSE;
 	gchar *tmpstring = NULL, *tmpstring2;
 	gchar **tmparray;
 	GList *rclist, *tmplist, *tmplist2;
@@ -211,7 +218,8 @@ static gboolean parse_config_file(GList * config_list, gchar * filename)
 	rclist = get_list(filename, rclist,FALSE);
 	
 	if (rclist == NULL) {
-		return FALSE;
+		DEBUG_MSG("no rclist, returning!\n");
+		return retval;
 	}
 
 	/* empty all variables that have type GList ('l') */
@@ -248,6 +256,7 @@ static gboolean parse_config_file(GList * config_list, gchar * filename)
 #endif
 				if (g_strncasecmp(tmpitem->identifier, tmpstring, strlen(tmpitem->identifier)) == 0) {
 					/* we have found the correct identifier */
+					retval = TRUE;
 					DEBUG_MSG("parse_config_file, identifier=%s, string=%s\n", tmpitem->identifier, tmpstring);
 					/* move pointer past the identifier */
 					tmpstring += strlen(tmpitem->identifier);
@@ -263,7 +272,7 @@ static gboolean parse_config_file(GList * config_list, gchar * filename)
 						strcpy((char *) *(void **) tmpitem->pointer, tmpstring);
 						break;
 					case 'e':
-						tmpstring2 = unescapestring(tmpstring);
+						tmpstring2 = unescape_string(tmpstring, FALSE); /* I wonder if that should be TRUE */
 						*(void **) tmpitem->pointer = (char *) realloc((char *) *(void **) tmpitem->pointer, strlen(tmpstring2) + 1);
 						strcpy((char *) *(void **) tmpitem->pointer, tmpstring2);
 						g_free(tmpstring2);
@@ -274,7 +283,7 @@ static gboolean parse_config_file(GList * config_list, gchar * filename)
 						DEBUG_MSG("parse_config_file, *(void **)tmpitem->pointer=%p\n", *(void **) tmpitem->pointer);
 						break;
 					case 'a':
-						tmparray = string_to_array(tmpstring, ':');
+						tmparray = string_to_array(tmpstring);
 						if (tmpitem->len <= 0 || tmpitem->len == count_array(tmparray)) {
 							* (void **) tmpitem->pointer = g_list_prepend((GList *) * (void **) tmpitem->pointer, tmparray);
 						} else {
@@ -295,111 +304,115 @@ static gboolean parse_config_file(GList * config_list, gchar * filename)
 	}
 	DEBUG_MSG("parse_config_file, parsed all entries, freeing list read from file\n");	
 	free_stringlist(rclist);
-	return TRUE;
+	return retval;
 }
 
 static GList *props_init_main(GList * config_rc)
 {
 /* these are used in the gtk-2 port already */
-	init_prop_integer   (&config_rc, &main_v->props.view_html_toolbar, "view_html_toolbar:", 1);
-	init_prop_integer   (&config_rc, &main_v->props.view_custom_menu, "view_custom_menu:", 1);
-	init_prop_integer   (&config_rc, &main_v->props.view_main_toolbar, "view_main_toolbar:", 1);
-	init_prop_integer   (&config_rc, &main_v->props.view_left_panel, "view_left_panel:", 1);
-	init_prop_integer   (&config_rc, &main_v->props.view_line_numbers, "view_line_numbers:", 1);
-	init_prop_integer   (&config_rc, &main_v->props.filebrowser_show_hidden_files, "fb_show_hidden_f:", 1);
-	init_prop_integer   (&config_rc, &main_v->props.filebrowser_show_others_files, "fb_show_others_f:", 1);
-	init_prop_integer   (&config_rc, &main_v->props.filebrowser_show_backup_files, "fb_show_backup_f:", 0);
+	init_prop_integer   (&config_rc, &main_v->props.view_html_toolbar, "view_html_toolbar:", 1, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.view_custom_menu, "view_custom_menu:", 1, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.view_main_toolbar, "view_main_toolbar:", 1, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.view_left_panel, "view_left_panel:", 1, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.view_line_numbers, "view_line_numbers:", 1, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.filebrowser_show_hidden_files, "fb_show_hidden_f:", 1, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.filebrowser_show_backup_files, "fb_show_backup_f:", 0, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.filebrowser_two_pane_view, "fb_two_pane_view:", 0, TRUE);
 	init_prop_string    (&config_rc, &main_v->props.filebrowser_unknown_icon, "fb_unknown_icon:", PKGDATADIR"icon_unknown.png");
 	init_prop_string    (&config_rc, &main_v->props.filebrowser_dir_icon, "fb_dir_icon:", PKGDATADIR"icon_dir.png");
 	init_prop_string    (&config_rc, &main_v->props.editor_font_string, "editor_font_string:", "courier 11");
-	init_prop_integer   (&config_rc, &main_v->props.editor_tab_width, "editor_tab_width:", 3);
+	init_prop_integer   (&config_rc, &main_v->props.editor_tab_width, "editor_tab_width:", 3, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.editor_indent_wspaces, "editor_indent_wspaces:", 0, TRUE);
 	init_prop_string    (&config_rc, &main_v->props.tab_font_string, "tab_font_string:", "");
-	init_prop_arraylist (&config_rc, &main_v->props.browsers, "browsers:", 2);
-	init_prop_arraylist (&config_rc, &main_v->props.external_commands, "external_commands:", 2);
-	init_prop_stringlist(&config_rc, &main_v->props.quickbar_items, "quickbar_items:");
-	init_prop_integer   (&config_rc, &main_v->props.highlight_num_lines_count, "highlight_num_lines_count:", 1);
-	init_prop_integer   (&config_rc, &main_v->props.defaulthighlight, "defaulthighlight:", 1);
+	init_prop_arraylist (&config_rc, &main_v->props.browsers, "browsers:", 2, TRUE);
+	init_prop_arraylist (&config_rc, &main_v->props.external_commands, "external_commands:", 2, TRUE);
+	init_prop_stringlist(&config_rc, &main_v->props.quickbar_items, "quickbar_items:", TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.highlight_num_lines_count, "highlight_num_lines_count:", 1, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.defaulthighlight, "defaulthighlight:", 1, TRUE);
 	/* old type filetypes have a different count, they are converted below */
-	init_prop_arraylist (&config_rc, &main_v->props.filetypes, "filetypes:", 0);
-	init_prop_integer   (&config_rc, &main_v->props.numcharsforfiletype, "numcharsforfiletype:", 200);
-	init_prop_arraylist (&config_rc, &main_v->props.filefilters, "filefilters:", 3);
+	init_prop_arraylist (&config_rc, &main_v->props.filetypes, "filetypes:", 0, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.numcharsforfiletype, "numcharsforfiletype:", 200, TRUE);
+	init_prop_arraylist (&config_rc, &main_v->props.filefilters, "filefilters:", 3, TRUE);
 	init_prop_string    (&config_rc, &main_v->props.last_filefilter, "last_filefilter:", "");
-	init_prop_integer   (&config_rc, &main_v->props.transient_htdialogs, "transient_htdialogs:", 1);
-	init_prop_integer   (&config_rc, &main_v->props.restore_dimensions, "restore_dimensions:", 1);	
-	init_prop_integer   (&config_rc, &main_v->props.left_panel_width, "left_panel_width:", 150);	
-	init_prop_integer   (&config_rc, &main_v->props.main_window_h, "main_window_height:", 400);
-	init_prop_integer   (&config_rc, &main_v->props.main_window_w, "main_window_width:", 600);
-	init_prop_integer   (&config_rc, &main_v->props.max_recent_files, "max_recent_files:", 15);
-	init_prop_integer   (&config_rc, &main_v->props.max_dir_history, "max_dir_history:", 10);
-	init_prop_integer   (&config_rc, &main_v->props.backup_file,"backup_file:",1);
+	init_prop_integer   (&config_rc, &main_v->props.transient_htdialogs, "transient_htdialogs:", 1, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.restore_dimensions, "restore_dimensions:", 1, TRUE);	
+	init_prop_integer   (&config_rc, &main_v->props.left_panel_width, "left_panel_width:", 150, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.two_pane_filebrowser_height, "two_pane_filebrowser_height:", 250, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.main_window_h, "main_window_height:", 400, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.main_window_w, "main_window_width:", 600, TRUE); /* negative width means maximized */
+	init_prop_integer   (&config_rc, &main_v->props.max_recent_files, "max_recent_files:", 15, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.max_dir_history, "max_dir_history:", 10, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.backup_file,"backup_file:",1, TRUE);
 	init_prop_string    (&config_rc, &main_v->props.backup_filestring,"backup_filestring:","~");
-	init_prop_integer    (&config_rc, &main_v->props.backup_abort_action,"backup_abort_action:",DOCUMENT_BACKUP_ABORT_ASK);
-	init_prop_integer   (&config_rc, &main_v->props.backup_cleanuponclose,"backup_cleanuponclose:",0);
+	init_prop_integer    (&config_rc, &main_v->props.backup_abort_action,"backup_abort_action:",DOCUMENT_BACKUP_ABORT_ASK, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.backup_cleanuponclose,"backup_cleanuponclose:",0, TRUE);
 	init_prop_string    (&config_rc, &main_v->props.image_thumbnailstring, "image_thumbnailstring:", "_thumbnail");
 	init_prop_string    (&config_rc, &main_v->props.image_thumbnailtype, "image_thumbnailtype:", "png");
-	init_prop_integer   (&config_rc, &main_v->props.image_thumbnail_refresh_quality,"image_thumbnail_refresh_quality:",1);
-	init_prop_integer   (&config_rc, &main_v->props.image_thumbnailsizing_type,"image_thumbnailsizing_type:",0);
-	init_prop_integer   (&config_rc, &main_v->props.image_thumbnailsizing_val1,"image_thumbnailsizing_val1:",100);
-	init_prop_integer   (&config_rc, &main_v->props.image_thumbnailsizing_val2,"image_thumbnailsizing_val2:",100);
+	init_prop_integer   (&config_rc, &main_v->props.image_thumbnail_refresh_quality,"image_thumbnail_refresh_quality:",1, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.image_thumbnailsizing_type,"image_thumbnailsizing_type:",0, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.image_thumbnailsizing_val1,"image_thumbnailsizing_val1:",100, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.image_thumbnailsizing_val2,"image_thumbnailsizing_val2:",100, TRUE);
 	init_prop_string    (&config_rc, &main_v->props.image_thumnailformatstring,"image_thumnailformatstring:","<a href=\"%r\"><img src=\"%t\" width=\"%x\" height=\"%y\" border=\"0\"></a>");
-	init_prop_integer   (&config_rc, &main_v->props.allow_multi_instances,"allow_multi_instances:",0);
-	init_prop_integer   (&config_rc, &main_v->props.num_undo_levels,"num_undo_levels:",100);
-	init_prop_integer   (&config_rc, &main_v->props.clear_undo_on_save,"clear_undo_on_save:",0);
+	init_prop_integer   (&config_rc, &main_v->props.allow_multi_instances,"allow_multi_instances:",0, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.modified_check_type,"modified_check_type:",1, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.num_undo_levels,"num_undo_levels:",100, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.clear_undo_on_save,"clear_undo_on_save:",0, TRUE);
 	init_prop_string    (&config_rc, &main_v->props.newfile_default_encoding,"newfile_default_encoding:","UTF-8");
-	init_prop_arraylist (&config_rc, &main_v->props.encodings, "encodings:", 2);
-	init_prop_integer   (&config_rc, &main_v->props.auto_set_encoding_meta,"auto_set_encoding_meta:",1);
-	init_prop_integer   (&config_rc, &main_v->props.auto_update_meta,"auto_update_meta:",1);
-	init_prop_arraylist (&config_rc, &main_v->props.outputbox, "outputbox:", 7);
-	init_prop_integer   (&config_rc, &main_v->props.ext_browsers_in_submenu,"ext_browsers_in_submenu:",0);
-	init_prop_integer   (&config_rc, &main_v->props.ext_commands_in_submenu,"ext_commands_in_submenu:",1);
-	init_prop_integer   (&config_rc, &main_v->props.ext_outputbox_in_submenu,"ext_outputbox_in_submenu:",1);
-	init_prop_arraylist (&config_rc, &main_v->props.reference_files, "reference_files:", 2);
-	init_prop_integer   (&config_rc, &main_v->props.fref_ldoubleclick_action,"fref_ldoubleclick_action:",0);
-	init_prop_integer   (&config_rc, &main_v->props.fref_info_type,"fref_info_type:",0);	
-	init_prop_integer   (&config_rc, &main_v->props.document_tabposition,"document_tabposition:",(gint)GTK_POS_BOTTOM);
-	init_prop_integer   (&config_rc, &main_v->props.leftpanel_tabposition,"leftpanel_tabposition:",(gint)GTK_POS_BOTTOM);
+	init_prop_arraylist (&config_rc, &main_v->props.encodings, "encodings:", 2, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.auto_set_encoding_meta,"auto_set_encoding_meta:",1, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.auto_update_meta,"auto_update_meta:",1, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.encoding_search_Nbytes, "encoding_search_Nbytes:", 500, TRUE);
+	init_prop_arraylist (&config_rc, &main_v->props.outputbox, "outputbox:", 7, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.ext_browsers_in_submenu,"ext_browsers_in_submenu:",0, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.ext_commands_in_submenu,"ext_commands_in_submenu:",1, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.ext_outputbox_in_submenu,"ext_outputbox_in_submenu:",1, TRUE);
+	init_prop_arraylist (&config_rc, &main_v->props.reference_files, "reference_files:", 2, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.fref_ldoubleclick_action,"fref_ldoubleclick_action:",0, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.fref_info_type,"fref_info_type:",0, TRUE);	
+	init_prop_integer   (&config_rc, &main_v->props.document_tabposition,"document_tabposition:",(gint)GTK_POS_BOTTOM, TRUE);
+	init_prop_integer   (&config_rc, &main_v->props.leftpanel_tabposition,"leftpanel_tabposition:",(gint)GTK_POS_BOTTOM, TRUE);
+	init_prop_string    (&config_rc, &main_v->props.default_basedir,"default_basedir:",g_get_home_dir());
+	init_prop_string    (&config_rc, &main_v->props.project_suffix,"project_suffix:",".bfproject");
 #ifdef HAVE_LIBASPELL
 	init_prop_string(&config_rc, &main_v->props.spell_default_lang, "spell_default_lang:", "en");
 #endif /* HAVE_LIBASPELL */
-	init_prop_integer   (&config_rc, &main_v->props.default_advanced_snr,"default_advanced_snr:",0);
-	init_prop_integer(&config_rc, &main_v->props.cont_highlight_full, "cont_highlight_full:", 1);
-	init_prop_integer(&config_rc, &main_v->props.lasttime_cust_menu, "lasttime_cust_menu:", 0);
-	init_prop_integer(&config_rc, &main_v->props.lasttime_highlighting, "lasttime_highlighting:", 0);
-	init_prop_integer(&config_rc, &main_v->props.lasttime_filetypes, "lasttime_filetypes:", 0);
-	init_prop_integer(&config_rc, &main_v->props.lasttime_encodings, "lasttime_encodings:", 0);
-
+	init_prop_integer(&config_rc, &main_v->props.cont_highlight_full, "cont_highlight_full:", 1, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.lasttime_cust_menu, "lasttime_cust_menu:", 0, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.lasttime_highlighting, "lasttime_highlighting:", 0, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.lasttime_filetypes, "lasttime_filetypes:", 0, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.lasttime_encodings, "lasttime_encodings:", 0, TRUE);
 	/* not yet in use */
 	init_prop_string(&config_rc, &main_v->props.image_editor_cline, "image_editor_command:", "gimp-remote -n \"%s\"&");
-	init_prop_integer(&config_rc, &main_v->props.full_p, "closing_paragraph_tag:", 1);
-	init_prop_integer(&config_rc, &main_v->props.full_li, "closing_list_item_tag:", 1);
-	init_prop_integer(&config_rc, &main_v->props.allow_css, "allow_the_use_of_css:", 1);
-	init_prop_integer(&config_rc, &main_v->props.allow_dep, "allow_the_use_of_font:", 1);
-	init_prop_integer(&config_rc, &main_v->props.format_by_context, "format_by_context:", 1);
-	init_prop_integer(&config_rc, &main_v->props.xhtml, "use_xhtml:", 0);
-	init_prop_integer(&config_rc, &main_v->props.allow_ruby, "allow_the_use_of_ruby:", 0);
-	init_prop_integer(&config_rc, &main_v->props.allow_h4, "allow_the_use_of_html4:", 1);
-	init_prop_integer(&config_rc, &main_v->props.allow_frames, "allow_the_use_of_frames:", 1);
-	init_prop_integer(&config_rc, &main_v->props.force_dtd, "force_an_dtd:", 0);
-	init_prop_integer(&config_rc, &main_v->props.dtd_url, "url_in_dtd:", 0);
-	init_prop_integer(&config_rc, &main_v->props.xml_start, "xml_starting_line:", 0);
-	init_prop_integer(&config_rc, &main_v->props.lowercase_tags, "lowercase_tags:", 1);
-	init_prop_integer(&config_rc, &main_v->props.word_wrap, "word_wrap:", 0);
-	init_prop_integer(&config_rc, &main_v->props.autoindent, "autoindent:", 1);
-	init_prop_integer(&config_rc, &main_v->props.fontset, "fontset:", 0);
-	init_prop_integer(&config_rc, &main_v->props.force_def_style, "force_white_background:", 1);
-	init_prop_integer(&config_rc, &main_v->props.drop_at_drop_pos, "drop_at_drop_position:", 0);
-	init_prop_integer(&config_rc, &main_v->props.link_management, "link_management:", 1);
+	init_prop_integer(&config_rc, &main_v->props.full_p, "closing_paragraph_tag:", 1, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.full_li, "closing_list_item_tag:", 1, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.allow_css, "allow_the_use_of_css:", 1, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.allow_dep, "allow_the_use_of_font:", 1, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.format_by_context, "format_by_context:", 1, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.xhtml, "use_xhtml:", 0, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.allow_ruby, "allow_the_use_of_ruby:", 0, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.allow_h4, "allow_the_use_of_html4:", 1, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.allow_frames, "allow_the_use_of_frames:", 1, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.force_dtd, "force_an_dtd:", 0, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.dtd_url, "url_in_dtd:", 0, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.xml_start, "xml_starting_line:", 0, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.lowercase_tags, "lowercase_tags:", 1, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.word_wrap, "word_wrap:", 0, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.autoindent, "autoindent:", 1, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.fontset, "fontset:", 0, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.force_def_style, "force_white_background:", 1, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.drop_at_drop_pos, "drop_at_drop_position:", 0, TRUE);
+	init_prop_integer(&config_rc, &main_v->props.link_management, "link_management:", 1, TRUE);
 	
-	init_prop_integer(&config_rc, &main_v->props.cont_highlight_update, "continuous_highlight_update:", 1);
+	init_prop_integer(&config_rc, &main_v->props.cont_highlight_update, "continuous_highlight_update:", 1, TRUE);
 	init_prop_string(&config_rc, &main_v->props.html_ver, "used_html_version:", "HTML 4.0 Transitional");
 	/* key conversion */
-	init_prop_integer (&config_rc, &main_v->props.conv_ctrl_enter,"conv_ctrl_enter:",0);
-	init_prop_integer (&config_rc, &main_v->props.conv_shift_enter,"conv_shift_enter:",0);
+	init_prop_integer (&config_rc, &main_v->props.conv_ctrl_enter,"conv_ctrl_enter:",0, TRUE);
+	init_prop_integer (&config_rc, &main_v->props.conv_shift_enter,"conv_shift_enter:",0, TRUE);
 	init_prop_string_with_escape (&config_rc, &main_v->props.shift_enter_text,"shift_enter_text:","<br>\\n");
 	init_prop_string_with_escape (&config_rc, &main_v->props.ctrl_enter_text,"ctrl_enter_text:","\\n</p>\\n<p>");
-	init_prop_integer (&config_rc, &main_v->props.conv_special_char,"conv_special_char:",0);
+	init_prop_integer (&config_rc, &main_v->props.conv_special_char,"conv_special_char:",0, TRUE);
 #ifdef WITH_MSG_QUEUE
-	init_prop_integer (&config_rc, &main_v->props.open_in_running_bluefish,"open_in_running_bluefish:",1);
+	init_prop_integer (&config_rc, &main_v->props.open_in_running_bluefish,"open_in_running_bluefish:",1, TRUE);
 #endif
 
 	return config_rc;
@@ -611,7 +624,7 @@ void rcfile_parse_highlighting(void) {
 	DEBUG_MSG("rcfile_parse_highlighting, started\n");
 
 	highlighting_configlist = NULL;
-	init_prop_arraylist(&highlighting_configlist, &main_v->props.highlight_patterns, "patterns:", 0);
+	init_prop_arraylist(&highlighting_configlist, &main_v->props.highlight_patterns, "patterns:", 0, TRUE);
 
 	filename = g_strconcat(g_get_home_dir(), "/.bluefish/highlighting", NULL);
 	defaultfile = return_first_existing_filename(PKGDATADIR"highlighting.default",
@@ -650,15 +663,16 @@ void rcfile_parse_custom_menu(void) {
 	DEBUG_MSG("rcfile_parse_custom_menu, started\n");
 
 	custom_menu_configlist = NULL;
-	init_prop_arraylist(&custom_menu_configlist, &main_v->props.cust_menu, "custom_menu:", 0);
-	init_prop_arraylist(&custom_menu_configlist, &main_v->props.cmenu_insert, "cmenu_insert:", 0);
-	init_prop_arraylist(&custom_menu_configlist, &main_v->props.cmenu_replace, "cmenu_replace:", 0);
+	init_prop_arraylist(&custom_menu_configlist, &main_v->props.cust_menu, "custom_menu:", 0, TRUE);
+	init_prop_arraylist(&custom_menu_configlist, &main_v->props.cmenu_insert, "cmenu_insert:", 0, TRUE);
+	init_prop_arraylist(&custom_menu_configlist, &main_v->props.cmenu_replace, "cmenu_replace:", 0, TRUE);
 
 	filename = g_strconcat(g_get_home_dir(), "/.bluefish/custom_menu", NULL);
 	defaultfile = return_first_existing_filename(PKGDATADIR"custom_menu.default",
 									"data/custom_menu.default",
 									"../data/custom_menu.default",NULL);
 	if (!parse_config_file(custom_menu_configlist, filename) || (main_v->props.cust_menu==NULL && main_v->props.cmenu_insert==NULL && main_v->props.cmenu_replace==NULL )) {
+		DEBUG_MSG("error parsing the custom menu file\n");
 		/* init the custom_menu in some way? */
 		if (defaultfile) {
 			parse_config_file(custom_menu_configlist, defaultfile);
@@ -668,8 +682,9 @@ void rcfile_parse_custom_menu(void) {
 	} else {
 		if (config_file_is_newer(main_v->props.lasttime_cust_menu,defaultfile)) {
 			GList *default_insert=NULL, *default_replace=NULL, *tmp_configlist=NULL;
-			init_prop_arraylist(&tmp_configlist, &default_insert, "cmenu_insert:", 0);
-			init_prop_arraylist(&tmp_configlist, &default_replace, "cmenu_replace:", 0);
+			DEBUG_MSG("config_file_is_newer!\n");
+			init_prop_arraylist(&tmp_configlist, &default_insert, "cmenu_insert:", 0, TRUE);
+			init_prop_arraylist(&tmp_configlist, &default_replace, "cmenu_replace:", 0, TRUE);
 			parse_config_file(tmp_configlist, defaultfile);
 			main_v->props.cmenu_insert = arraylist_load_new_identifiers_from_list(main_v->props.cmenu_insert, default_insert, 1);
 			main_v->props.cmenu_replace = arraylist_load_new_identifiers_from_list(main_v->props.cmenu_replace, default_replace, 1);
@@ -682,11 +697,13 @@ void rcfile_parse_custom_menu(void) {
 	/* for backwards compatibility with older (before Bluefish 0.10) custom menu files we can convert those.. 
 	we will not need the 'type' anymore, since we will put them in separate lists, hence the memmove() call
 	*/
+	DEBUG_MSG("main_v->props.cust_menu=%p\n",main_v->props.cust_menu);
 	if (main_v->props.cust_menu) {
 		GList *tmplist= g_list_first(main_v->props.cust_menu);
 		while (tmplist) {
 			gchar **strarr = (gchar **)tmplist->data;
 			gint count = count_array(strarr);
+			DEBUG_MSG("converting cust_menu, found count=%d\n",count);
 			if (count >= 5 && strarr[1][0] == '0') {
 				DEBUG_MSG("rcfile_parse_custom_menu, converting insert, 0=%s, 1=%s\n", strarr[0], strarr[1]);
 				g_free(strarr[1]);
@@ -718,7 +735,7 @@ void rcfile_parse_custom_menu(void) {
 			tmplist = g_list_next(tmplist);
 		}
 		g_list_free(main_v->props.cust_menu);
-		main_v->props.cust_menu = NULL;
+		main_v->props.cust_menu=NULL;
 	}
 	
 /*		main_v->props.cust_menu = g_list_append(main_v->props.cust_menu, array_from_arglist(N_("/php/ibase/ibase fetch row"), "0", "while ($%1 = ibase_fetch_row($%0)) {\n	echo $%1[0];\n", "\n}\nibase_free_result($%0);\n", "2", _("ibase result variable name"), _("row variable name"), NULL));
@@ -820,3 +837,45 @@ void rcfile_save_all(void) {
 	rcfile_save_custom_menu();
 }
 
+static GList *return_project_configlist(Tproject *project) {
+	GList *configlist = NULL;
+	init_prop_string(&configlist, &project->name,"name:",_("Untitled Project"));
+	init_prop_stringlist(&configlist, &project->files, "files:", FALSE);
+	init_prop_string(&configlist, &project->basedir,"basedir:","");
+	init_prop_string(&configlist, &project->webdir,"webdir:","");
+	init_prop_string(&configlist, &project->template,"template:","");
+	init_prop_stringlist(&configlist, &project->recentfiles, "recentfiles:", FALSE);
+	init_prop_integer (&configlist, &project->view_main_toolbar,"view_main_toolbar:",1,FALSE);
+	init_prop_integer (&configlist, &project->view_left_panel,"view_left_panel:",1,FALSE);
+	init_prop_integer (&configlist, &project->view_custom_menu,"view_custom_menu:",1,FALSE);
+	init_prop_integer (&configlist, &project->view_html_toolbar,"view_html_toolbar:",1,FALSE);
+	init_prop_integer (&configlist, &project->word_wrap,"word_wrap:",1,FALSE);
+
+	init_prop_stringlist(&configlist, &project->session->searchlist, "searchlist:", FALSE);
+	init_prop_stringlist(&configlist, &project->session->replacelist, "replacelist:", FALSE);
+	init_prop_stringlist(&configlist, &project->session->classlist, "classlist:", FALSE);
+	init_prop_stringlist(&configlist, &project->session->colorlist, "colorlist:", FALSE);
+	init_prop_stringlist(&configlist, &project->session->targetlist, "targetlist:", FALSE);
+	init_prop_stringlist(&configlist, &project->session->urllist, "urllist:", FALSE);
+	init_prop_stringlist(&configlist, &project->session->fontlist, "fontlist:", FALSE);
+	init_prop_stringlist(&configlist, &project->session->dtd_cblist, "dtd_cblist:", FALSE);
+
+	return configlist;
+}
+
+gboolean rcfile_parse_project(Tproject *project, gchar *filename) {
+	gboolean retval;
+	GList *configlist = return_project_configlist(project);
+	retval = parse_config_file(configlist, filename);
+	free_configlist(configlist);
+	return retval;
+}
+
+gboolean rcfile_save_project(Tproject *project, gchar *filename) {
+	gboolean retval;
+	GList *configlist = return_project_configlist(project);
+	DEBUG_MSG("rcfile_save_project, project %p, name='%s', basedir='%s', webdir='%s'\n",project, project->name, project->basedir, project->webdir);
+	retval = save_config_file(configlist, filename);
+	free_configlist(configlist);
+	return retval;
+}
