@@ -26,4 +26,6 @@ void rcfile_parse_custom_menu(void);
 void rcfile_check_directory(void);
 void rcfile_save_configfile_menu_cb(gpointer callback_data,guint action,GtkWidget *widget);
 void rcfile_save_all(void);
+gboolean rcfile_parse_project(Tproject *project, gchar *filename);
+gboolean rcfile_save_project(Tproject *project, gchar *filename);
 #endif /* __RCFILE_H_ */
