@@ -362,17 +362,17 @@ void estrl_dialog(GList **which_list, gchar *title, gint what_list
 	}
 	gtk_clist_thaw(GTK_CLIST(estrl->clist));
 
-	but = bf_stock_button(_(" Add "), G_CALLBACK(estrl_add_clicked_lcb), estrl);
+	but = bf_generic_mnemonic_button(_(" Add "), G_CALLBACK(estrl_add_clicked_lcb), estrl);
 	gtk_box_pack_start(GTK_BOX(vbox2),but , TRUE, TRUE, 0);
-	but = bf_stock_button(_(" Update "), G_CALLBACK(estrl_update_clicked_lcb), estrl);
+	but = bf_generic_mnemonic_button(_(" Update "), G_CALLBACK(estrl_update_clicked_lcb), estrl);
 	gtk_box_pack_start(GTK_BOX(vbox2),but , TRUE, TRUE, 0);
-	but = bf_stock_button(_(" Delete "), G_CALLBACK(estrl_delete_clicked_lcb), estrl);
+	but = bf_generic_mnemonic_button(_(" Delete "), G_CALLBACK(estrl_delete_clicked_lcb), estrl);
 	gtk_box_pack_start(GTK_BOX(vbox2),but , TRUE, TRUE, 0);
-	but = bf_stock_button(_(" Up "), G_CALLBACK(estrl_up_clicked_lcb), estrl);
+	but = bf_generic_mnemonic_button(_(" Up "), G_CALLBACK(estrl_up_clicked_lcb), estrl);
 	gtk_box_pack_start(GTK_BOX(vbox2),but , TRUE, TRUE, 0);
-	but = bf_stock_button(_(" Down "), G_CALLBACK(estrl_down_clicked_lcb), estrl);
+	but = bf_generic_mnemonic_button(_(" Down "), G_CALLBACK(estrl_down_clicked_lcb), estrl);
 	gtk_box_pack_start(GTK_BOX(vbox2),but , TRUE, TRUE, 0);
-	but = bf_stock_button(_(" Sort "), G_CALLBACK(estrl_sort_clicked_lcb), estrl);
+	but = bf_generic_mnemonic_button(_(" Sort "), G_CALLBACK(estrl_sort_clicked_lcb), estrl);
 	gtk_box_pack_start(GTK_BOX(vbox2),but , TRUE, TRUE, 0);
 
 	hbox = gtk_hbutton_box_new();
@@ -462,7 +462,7 @@ gint count_array(gchar **array) {
  *
  * Return value: #gchar* newly allocated string
  */
-gchar *array_to_string(gchar **array, gchar delimiter) {
+gchar *array_to_string(gchar **array) {
 	if (array) {
 		gchar **tmp, *escaped1, *finalstring;
 		gint newsize=1;
@@ -471,11 +471,11 @@ gchar *array_to_string(gchar **array, gchar delimiter) {
 		tmp = array;
 		while(*tmp) {
 			DEBUG_MSG("array_to_string, *tmp = %s\n", *tmp);
-			escaped1 = escapestring(*tmp, delimiter);
+			escaped1 = escape_string(*tmp, TRUE);
 			newsize += strlen(escaped1)+1;
 			finalstring = g_realloc(finalstring, newsize);
 			strcat(finalstring, escaped1);
-			finalstring[newsize-2] = delimiter;
+			finalstring[newsize-2] = ':';
 			finalstring[newsize-1] = '\0';
 			g_free(escaped1);
 			tmp++;
@@ -505,7 +505,7 @@ gchar *array_to_string(gchar **array, gchar delimiter) {
  *
  * Return value: #gchar** newly allocated NULL terminated array
  */
-gchar **string_to_array(gchar *string, gchar delimiter) {
+gchar **string_to_array(gchar *string) {
 	gchar **array;
 	gchar *tmpchar, *tmpchar2;
 	gchar *newstring;
@@ -541,17 +541,16 @@ gchar **string_to_array(gchar *string, gchar delimiter) {
 				newstring[count] = '\t';
 				tmpchar++;
 			break;
+			case ':':
+				newstring[count] = ':';
+				tmpchar++;
+			break;
 			default:
-				if (*tmpchar2 == delimiter) {
-					newstring[count] = delimiter;
-					tmpchar++;
-				} else {
-					DEBUG_MSG("string_to_array, weird, an unescaped backslash ?\n");
-					newstring[count] = '\\';
-				}
+				DEBUG_MSG("string_to_array, weird, an unescaped backslash ?\n");
+				newstring[count] = '\\';
 			break;
 			}
-		} else if (*tmpchar == delimiter) {
+		} else if (*tmpchar == ':') {
 			newstring[count] = '\0';  /* end of the current newstring */
 			DEBUG_MSG("string_to_array, newstring(%p)=%s\n", newstring, newstring);
 			array[arraycount] = g_strdup(newstring);
@@ -747,7 +746,7 @@ GList *get_list(const gchar * filename, GList * which_list, gboolean is_arraylis
 			tmpbuf = trunc_on_char(tmpbuf, '\n');
 			tempstr = g_strdup(tmpbuf);
 			if (is_arraylist) {
-				gchar **temparr = string_to_array(tempstr, ':');
+				gchar **temparr = string_to_array(tempstr);
 				which_list = g_list_append(which_list, temparr);
 				g_free(tempstr);
 			} else {
@@ -767,10 +766,17 @@ GList *get_stringlist(const gchar * filename, GList * which_list) {
 	return get_list(filename,which_list,FALSE);
 }
 
-/*****************************************************************************
- * stores a stringlist into a file
+/**
+ * put_stringlist_limited:
+ * @filename: #gchar* with the filename to store the list
+ * @which_list: #GList* with the list to store
+ * @maxentries: #gint only the LAST maxentries of the list will be stored
+ *
+ * stores the LAST maxentries entries of list which_list in file filename
+ * if maxentries is 0 all entries will be stored
+ *
+ * Return value: #gboolean TRUE on success, FALSE on failure
  */
-
 gboolean put_stringlist_limited(gchar * filename, GList * which_list, gint maxentries) {
 	FILE *fd;
 	GList *tmplist;
@@ -826,20 +832,63 @@ GList *remove_from_stringlist(GList *which_list, const gchar * string) {
 	return which_list;
 }
 
-GList *add_to_history_stringlist(GList *which_list, const gchar *string) {
+static void unlink_before(GList *tmplist) {
+	GList *prev = tmplist->prev;
+	if (prev) {
+		prev->next = NULL;
+	}
+	tmplist->prev = NULL;
+}
+
+GList *limit_stringlist(GList *which_list, gint num_entries, gboolean keep_end) {
+	GList *retlist, *freelist;
+	if (keep_end) {
+		gint len;
+		freelist = g_list_first(which_list);
+		len = g_list_length(freelist);
+		if (len <= num_entries) return which_list;
+		retlist = g_list_nth(freelist, len - num_entries);
+		unlink_before(retlist);
+	} else {
+		retlist = g_list_first(which_list);
+		freelist = g_list_nth(retlist, num_entries);
+		if (freelist) unlink_before(freelist);
+	}
+	if (freelist) free_stringlist(freelist);
+	return retlist;
+}
+
+/**
+ * add_to_history_stringlist:
+ * @which_list: #GList* the list to add to
+ * @string: #const gchar* with the string to add
+ * @move_to_end: #gboolean, if TRUE do move existing entries to the end
+ *
+ * adds string to the stringlist which_list
+ *
+ * if string exists in this list already and move_to_end is TRUE, 
+ * it will be moved to the end of the list
+ *
+ * Return value: GList* with the modified list
+ */
+GList *add_to_history_stringlist(GList *which_list, const gchar *string, gboolean move_to_end) {
 	if (string && strlen(string) ) {
 		GList *tmplist = g_list_first(which_list);
 		while (tmplist) {
 			if (strcmp((gchar *) tmplist->data, string) == 0) {
 				/* move this entry to the end */
-				DEBUG_MSG("add_to_history_stringlist, entry exists, moving to the end\n");
-				which_list = g_list_remove_link(which_list, tmplist);
-				return g_list_concat(which_list, tmplist);
+				if (move_to_end) {
+					DEBUG_MSG("add_to_history_stringlist, entry %s exists, moving to the end\n", string);
+					which_list = g_list_remove_link(which_list, tmplist);
+					return g_list_concat(which_list, tmplist);
+				} else {
+					return which_list;
+				}
 			}
 			tmplist = g_list_next(tmplist);
 		}
 		/* if we arrive here the string was not yet in the list */
-		DEBUG_MSG("add_to_history_stringlist, appending new entry\n");
+		DEBUG_MSG("add_to_history_stringlist, appending new entry %s\n",string);
 		which_list = g_list_append(which_list, g_strdup(string));
 	}
 	return which_list;
@@ -915,7 +964,10 @@ gboolean arraylist_value_exists(GList *arraylist, gchar **value, gint testlevel)
 		gint i=0;
 		gboolean equal = TRUE;
 		while (i<testlevel && equal) {
-			if (strcmp(tmparr[i],value[i])!=0) {
+			/*  tmparr[i]==value[i] will only happen when they are both NULL	*/
+			if (tmparr[i] == NULL && value[i] == NULL) {
+				break;
+			} else if (tmparr[i]==NULL || value[i] == NULL || strcmp(tmparr[i],value[i])!=0) {
 				equal = FALSE;
 			}
 			i++;
