@@ -28,8 +28,8 @@
 				, gint column_num, gchar **column_titles, void (*post_dialog_func)());*/
 
 gint count_array(gchar **array);
-gchar *array_to_string(gchar **array, gchar delimiter);
-gchar **string_to_array(gchar *string, gchar delimiter);
+gchar *array_to_string(gchar **array);
+gchar **string_to_array(gchar *string);
 gchar **array_from_arglist(const gchar *string1, ...);
 
 GList *duplicate_stringlist(GList *list, gint dup_data);
@@ -45,7 +45,8 @@ GList *duplicate_arraylist(GList *arraylist);
 
 /* removes a string from a stringlist if it is the same */
 GList *remove_from_stringlist(GList *which_list, const gchar * string);
-GList *add_to_history_stringlist(GList *which_list, const gchar *string);
+GList *limit_stringlist(GList *which_list, gint num_entries, gboolean keep_end);
+GList *add_to_history_stringlist(GList *which_list, const gchar *string, gboolean move_to_end);
 /* adds a string to a stringlist if it is not yet in there */
 GList *add_to_stringlist(GList * which_list, const gchar * string);
 gchar *stringlist_to_string(GList *stringlist, gchar *delimiter);
